# -*- coding: utf-8 -*-
info = {
    "name": "to",
    "date_order": "DMY",
    "january": [
        "sānuali",
        "sān"
    ],
    "february": [
        "fēpueli",
        "fēp"
    ],
    "march": [
        "ma'asi",
        "ma'a"
    ],
    "april": [
        "'epeleli",
        "'epe"
    ],
    "may": [
        "mē"
    ],
    "june": [
        "sune",
        "sun"
    ],
    "july": [
        "siulai",
        "siu"
    ],
    "august": [
        "'aokosi",
        "'aok"
    ],
    "september": [
        "sepitema",
        "sep"
    ],
    "october": [
        "'okatopa",
        "'oka"
    ],
    "november": [
        "nōvema",
        "nōv"
    ],
    "december": [
        "tīsema",
        "tīs"
    ],
    "monday": [
        "mōnite",
        "mōn"
    ],
    "tuesday": [
        "tūsite",
        "tūs"
    ],
    "wednesday": [
        "pulelulu",
        "pul"
    ],
    "thursday": [
        "tu'apulelulu",
        "tu'a"
    ],
    "friday": [
        "falaite",
        "fal"
    ],
    "saturday": [
        "tokonaki",
        "tok"
    ],
    "sunday": [
        "sāpate",
        "sāp"
    ],
    "am": [
        "hh",
        "am",
        "hengihengi"
    ],
    "pm": [
        "ea",
        "pm",
        "efiafi"
    ],
    "year": [
        "ta'u"
    ],
    "month": [
        "māhina"
    ],
    "week": [
        "uike"
    ],
    "day": [
        "'aho"
    ],
    "hour": [
        "houa"
    ],
    "minute": [
        "miniti"
    ],
    "second": [
        "sekoni"
    ],
    "relative-type": {
        "1 year ago": [
            "ta'u kuo'osi"
        ],
        "0 year ago": [
            "ta'ú ni"
        ],
        "in 1 year": [
            "ta'u kaha'u"
        ],
        "1 month ago": [
            "māhina kuo'osi"
        ],
        "0 month ago": [
            "māhiná ni"
        ],
        "in 1 month": [
            "māhina kaha'u"
        ],
        "1 week ago": [
            "uike kuo'osi"
        ],
        "0 week ago": [
            "uiké ni"
        ],
        "in 1 week": [
            "uike kaha'u"
        ],
        "1 day ago": [
            "'aneafi"
        ],
        "0 day ago": [
            "'ahó ni"
        ],
        "in 1 day": [
            "'apongipongi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "taimí ni"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "'i he ta'u 'e (\\d+)"
        ],
        "\\1 year ago": [
            "ta'u 'e (\\d+) kuo'osi"
        ],
        "in \\1 month": [
            "'i he māhina 'e (\\d+)"
        ],
        "\\1 month ago": [
            "māhina 'e (\\d+) kuo'osi"
        ],
        "in \\1 week": [
            "'i he uike 'e (\\d+)"
        ],
        "\\1 week ago": [
            "uike 'e (\\d+) kuo'osi"
        ],
        "in \\1 day": [
            "'i he 'aho 'e (\\d+)"
        ],
        "\\1 day ago": [
            "'aho 'e (\\d+) kuo'osi"
        ],
        "in \\1 hour": [
            "'i he houa 'e (\\d+)"
        ],
        "\\1 hour ago": [
            "houa 'e (\\d+) kuo'osi"
        ],
        "in \\1 minute": [
            "'i he miniti 'e (\\d+)"
        ],
        "\\1 minute ago": [
            "miniti 'e (\\d+) kuo'osi"
        ],
        "in \\1 second": [
            "'i he sekoni 'e (\\d+)"
        ],
        "\\1 second ago": [
            "sekoni 'e (\\d+) kuo'osi"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
