# -*- coding: utf-8 -*-
info = {
    "name": "gsw",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "märz",
        "mär"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "auguscht",
        "aug"
    ],
    "september": [
        "septämber",
        "sep"
    ],
    "october": [
        "oktoober",
        "okt"
    ],
    "november": [
        "novämber",
        "nov"
    ],
    "december": [
        "dezämber",
        "dez"
    ],
    "monday": [
        "määntig",
        "mä"
    ],
    "tuesday": [
        "ziischtig",
        "zi"
    ],
    "wednesday": [
        "mittwuch",
        "mi"
    ],
    "thursday": [
        "dunschtig",
        "du"
    ],
    "friday": [
        "friitig",
        "fr"
    ],
    "saturday": [
        "samschtig",
        "sa"
    ],
    "sunday": [
        "sunntig",
        "su"
    ],
    "am": [
        "vormittag",
        "vorm",
        "am vormittag"
    ],
    "pm": [
        "namittag",
        "nam",
        "am namittag"
    ],
    "year": [
        "jaar"
    ],
    "month": [
        "monet"
    ],
    "week": [
        "wuche"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "schtund"
    ],
    "minute": [
        "minuute"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "geschter"
        ],
        "0 day ago": [
            "hüt"
        ],
        "in 1 day": [
            "moorn"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {
        "gsw-LI": {
            "name": "gsw-LI"
        },
        "gsw-FR": {
            "name": "gsw-FR"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
