# -*- coding: utf-8 -*-
info = {
    "name": "nmg",
    "date_order": "DMY",
    "january": [
        "ngwɛn matáhra",
        "ng1"
    ],
    "february": [
        "ngwɛn ńmba",
        "ng2"
    ],
    "march": [
        "ngwɛn ńlal",
        "ng3"
    ],
    "april": [
        "ngwɛn ńna",
        "ng4"
    ],
    "may": [
        "ngwɛn ńtan",
        "ng5"
    ],
    "june": [
        "ngwɛn ńtuó",
        "ng6"
    ],
    "july": [
        "ngwɛn hɛmbuɛrí",
        "ng7"
    ],
    "august": [
        "ngwɛn lɔmbi",
        "ng8"
    ],
    "september": [
        "ngwɛn rɛbvuâ",
        "ng9"
    ],
    "october": [
        "ngwɛn wum",
        "ng10"
    ],
    "november": [
        "ngwɛn wum navǔr",
        "ng11"
    ],
    "december": [
        "krísimin",
        "kris"
    ],
    "monday": [
        "mɔ́ndɔ",
        "mɔ́n"
    ],
    "tuesday": [
        "sɔ́ndɔ mafú mába",
        "smb"
    ],
    "wednesday": [
        "sɔ́ndɔ mafú málal",
        "sml"
    ],
    "thursday": [
        "sɔ́ndɔ mafú mána",
        "smn"
    ],
    "friday": [
        "mabágá má sukul",
        "mbs"
    ],
    "saturday": [
        "sásadi",
        "sas"
    ],
    "sunday": [
        "sɔ́ndɔ",
        "sɔ́n"
    ],
    "am": [
        "maná"
    ],
    "pm": [
        "kugú"
    ],
    "year": [
        "mbvu"
    ],
    "month": [
        "ngwɛn"
    ],
    "week": [
        "sɔ́ndɔ"
    ],
    "day": [
        "duö"
    ],
    "hour": [
        "wulā"
    ],
    "minute": [
        "mpálâ"
    ],
    "second": [
        "nyiɛl"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nakugú"
        ],
        "0 day ago": [
            "dɔl"
        ],
        "in 1 day": [
            "namáná"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
