# -*- coding: utf-8 -*-
info = {
    "name": "cs",
    "date_order": "DMY",
    "january": [
        "leden",
        "led",
        "ledna"
    ],
    "february": [
        "únor",
        "úno",
        "února"
    ],
    "march": [
        "březen",
        "bře",
        "března"
    ],
    "april": [
        "duben",
        "dub",
        "dubna"
    ],
    "may": [
        "květen",
        "kvě",
        "května"
    ],
    "june": [
        "červen",
        "čvn",
        "června",
        "Čer"
    ],
    "july": [
        "červenec",
        "čvc",
        "července",
        "Črc"
    ],
    "august": [
        "srpen",
        "srp",
        "srpna"
    ],
    "september": [
        "září",
        "zář"
    ],
    "october": [
        "říjen",
        "říj",
        "října"
    ],
    "november": [
        "listopad",
        "lis",
        "listopadu"
    ],
    "december": [
        "prosinec",
        "pro",
        "prosince"
    ],
    "monday": [
        "pondělí",
        "po",
        "Pon"
    ],
    "tuesday": [
        "úterý",
        "út",
        "Úte"
    ],
    "wednesday": [
        "středa",
        "st",
        "Stř",
        "Středu"
    ],
    "thursday": [
        "čtvrtek",
        "čt",
        "Čtv"
    ],
    "friday": [
        "pátek",
        "pá",
        "Pát"
    ],
    "saturday": [
        "sobota",
        "so",
        "Sob",
        "Sobotu"
    ],
    "sunday": [
        "neděle",
        "ne",
        "Ned",
        "Neděli"
    ],
    "am": [
        "dop"
    ],
    "pm": [
        "odp"
    ],
    "year": [
        "rok",
        "r",
        "roků",
        "roky"
    ],
    "month": [
        "měsíc",
        "měs",
        "měsíců",
        "měsíce"
    ],
    "week": [
        "týden",
        "týd",
        "týdnů",
        "týdny"
    ],
    "day": [
        "den",
        "dnů",
        "dny"
    ],
    "hour": [
        "hodina",
        "h",
        "hodin",
        "hodiny",
        "hodinu",
        "hodinami"
    ],
    "minute": [
        "minuta",
        "min",
        "minut",
        "minuty"
    ],
    "second": [
        "sekunda",
        "s",
        "sekundy",
        "sekund",
        "vteřina",
        "vteřin",
        "vteřiny"
    ],
    "relative-type": {
        "1 year ago": [
            "minulý rok"
        ],
        "0 year ago": [
            "tento rok"
        ],
        "in 1 year": [
            "příští rok"
        ],
        "1 month ago": [
            "minulý měsíc"
        ],
        "0 month ago": [
            "tento měsíc"
        ],
        "in 1 month": [
            "příští měsíc"
        ],
        "1 week ago": [
            "minulý týden",
            "minulý týd"
        ],
        "0 week ago": [
            "tento týden",
            "tento týd"
        ],
        "in 1 week": [
            "příští týden",
            "příští týd"
        ],
        "1 day ago": [
            "včera"
        ],
        "0 day ago": [
            "dnes"
        ],
        "in 1 day": [
            "zítra"
        ],
        "0 hour ago": [
            "tuto hodinu"
        ],
        "0 minute ago": [
            "tuto minutu"
        ],
        "0 second ago": [
            "nyní"
        ],
        "2 day ago": [
            "předevčírem"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) rok",
            "za (\\d+) let",
            "za (\\d+) r",
            "za (\\d+) l"
        ],
        "\\1 year ago": [
            "před (\\d+) rokem",
            "před (\\d+) lety",
            "před (\\d+) r",
            "před (\\d+) l"
        ],
        "in \\1 month": [
            "za (\\d+) měsíc",
            "za (\\d+) měsíců",
            "za (\\d+) měs"
        ],
        "\\1 month ago": [
            "před (\\d+) měsícem",
            "před (\\d+) měsíci",
            "před (\\d+) měs"
        ],
        "in \\1 week": [
            "za (\\d+) týden",
            "za (\\d+) týdnů",
            "za (\\d+) týd"
        ],
        "\\1 week ago": [
            "před (\\d+) týdnem",
            "před (\\d+) týdny",
            "před (\\d+) týd"
        ],
        "in \\1 day": [
            "za (\\d+) den",
            "za (\\d+) dní"
        ],
        "\\1 day ago": [
            "před (\\d+) dnem",
            "před (\\d+) dny"
        ],
        "in \\1 hour": [
            "za (\\d+) hodinu",
            "za (\\d+) hodin",
            "za (\\d+) h"
        ],
        "\\1 hour ago": [
            "před (\\d+) hodinou",
            "před (\\d+) hodinami",
            "před (\\d+) h"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minut",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "před (\\d+) minutou",
            "před (\\d+) minutami",
            "před (\\d+) min"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekund",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "před (\\d+) sekundou",
            "před (\\d+) sekundami",
            "před (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        "přibližně",
        "v",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "před"
    ],
    "in": [
        "ve",
        "v"
    ]
}
