# -*- coding: utf-8 -*-
info = {
    "name": "ak",
    "date_order": "YMD",
    "january": [
        "sanda-ɔpɛpɔn",
        "s-ɔ"
    ],
    "february": [
        "kwakwar-ɔgyefuo",
        "k-ɔ"
    ],
    "march": [
        "ebɔw-ɔbenem",
        "e-ɔ"
    ],
    "april": [
        "ebɔbira-oforisuo",
        "e-o"
    ],
    "may": [
        "esusow aketseaba-kɔtɔnimba",
        "e-k"
    ],
    "june": [
        "obirade-ayɛwohomumu",
        "o-a"
    ],
    "july": [
        "ayɛwoho-kitawonsa",
        "a-k"
    ],
    "august": [
        "difuu-ɔsandaa",
        "d-ɔ"
    ],
    "september": [
        "fankwa-ɛbɔ",
        "f-ɛ"
    ],
    "october": [
        "ɔbɛsɛ-ahinime",
        "ɔ-a"
    ],
    "november": [
        "ɔberɛfɛw-obubuo",
        "ɔ-o"
    ],
    "december": [
        "mumu-ɔpɛnimba",
        "m-ɔ"
    ],
    "monday": [
        "dwowda",
        "dwo"
    ],
    "tuesday": [
        "benada",
        "ben"
    ],
    "wednesday": [
        "wukuda",
        "wuk"
    ],
    "thursday": [
        "yawda",
        "yaw"
    ],
    "friday": [
        "fida",
        "fia"
    ],
    "saturday": [
        "memeneda",
        "mem"
    ],
    "sunday": [
        "kwesida",
        "kwe"
    ],
    "am": [
        "an"
    ],
    "pm": [
        "ew"
    ],
    "year": [
        "afe"
    ],
    "month": [
        "bosome"
    ],
    "week": [
        "dapɛn"
    ],
    "day": [
        "da"
    ],
    "hour": [
        "dɔnhwer"
    ],
    "minute": [
        "sema"
    ],
    "second": [
        "sɛkɛnd"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ndeda"
        ],
        "0 day ago": [
            "ndɛ"
        ],
        "in 1 day": [
            "ɔkyena"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
