# -*- coding: utf-8 -*-
info = {
    "name": "et",
    "date_order": "DMY",
    "january": [
        "jaanuar",
        "jaan"
    ],
    "february": [
        "veebruar",
        "veebr"
    ],
    "march": [
        "märts"
    ],
    "april": [
        "aprill",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juuni"
    ],
    "july": [
        "juuli"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sept"
    ],
    "october": [
        "oktoober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "detsember",
        "dets"
    ],
    "monday": [
        "esmaspäev",
        "e"
    ],
    "tuesday": [
        "teisipäev",
        "t"
    ],
    "wednesday": [
        "kolmapäev",
        "k"
    ],
    "thursday": [
        "neljapäev",
        "n"
    ],
    "friday": [
        "reede",
        "r"
    ],
    "saturday": [
        "laupäev",
        "l"
    ],
    "sunday": [
        "pühapäev",
        "p"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "aasta",
        "a"
    ],
    "month": [
        "kuu",
        "k"
    ],
    "week": [
        "nädal",
        "näd"
    ],
    "day": [
        "päev",
        "p"
    ],
    "hour": [
        "tund",
        "t"
    ],
    "minute": [
        "minut",
        "min"
    ],
    "second": [
        "sekund",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "eelmine aasta"
        ],
        "0 year ago": [
            "käesolev aasta"
        ],
        "in 1 year": [
            "järgmine aasta"
        ],
        "1 month ago": [
            "eelmine kuu"
        ],
        "0 month ago": [
            "käesolev kuu"
        ],
        "in 1 month": [
            "järgmine kuu"
        ],
        "1 week ago": [
            "eelmine nädal"
        ],
        "0 week ago": [
            "käesolev nädal"
        ],
        "in 1 week": [
            "järgmine nädal"
        ],
        "1 day ago": [
            "eile"
        ],
        "0 day ago": [
            "täna"
        ],
        "in 1 day": [
            "homme"
        ],
        "0 hour ago": [
            "praegusel tunnil"
        ],
        "0 minute ago": [
            "praegusel minutil"
        ],
        "0 second ago": [
            "nüüd"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) aasta pärast",
            "(\\d+) a pärast"
        ],
        "\\1 year ago": [
            "(\\d+) aasta eest",
            "(\\d+) a eest"
        ],
        "in \\1 month": [
            "(\\d+) kuu pärast",
            "(\\d+) k pärast"
        ],
        "\\1 month ago": [
            "(\\d+) kuu eest",
            "(\\d+) k eest"
        ],
        "in \\1 week": [
            "(\\d+) nädala pärast",
            "(\\d+) näd pärast"
        ],
        "\\1 week ago": [
            "(\\d+) nädala eest",
            "(\\d+) näd eest"
        ],
        "in \\1 day": [
            "(\\d+) päeva pärast",
            "(\\d+) p pärast"
        ],
        "\\1 day ago": [
            "(\\d+) päeva eest",
            "(\\d+) p eest"
        ],
        "in \\1 hour": [
            "(\\d+) tunni pärast",
            "(\\d+) t pärast"
        ],
        "\\1 hour ago": [
            "(\\d+) tunni eest",
            "(\\d+) t eest"
        ],
        "in \\1 minute": [
            "(\\d+) minuti pärast",
            "(\\d+) min pärast"
        ],
        "\\1 minute ago": [
            "(\\d+) minuti eest",
            "(\\d+) min eest"
        ],
        "in \\1 second": [
            "(\\d+) sekundi pärast",
            "(\\d+) sek pärast",
            "(\\d+) s pärast"
        ],
        "\\1 second ago": [
            "(\\d+) sekundi eest",
            "(\\d+) sek eest",
            "(\\d+) s eest"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
