# -*- coding: utf-8 -*-
info = {
    "name": "nn",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "måndag",
        "mån",
        "må"
    ],
    "tuesday": [
        "tysdag",
        "tys",
        "ty"
    ],
    "wednesday": [
        "onsdag",
        "ons",
        "on"
    ],
    "thursday": [
        "torsdag",
        "tor",
        "to"
    ],
    "friday": [
        "fredag",
        "fre",
        "fr"
    ],
    "saturday": [
        "laurdag",
        "lau",
        "la"
    ],
    "sunday": [
        "søndag",
        "søn",
        "sø"
    ],
    "am": [
        "fm",
        "formiddag"
    ],
    "pm": [
        "em",
        "ettermiddag"
    ],
    "year": [
        "år"
    ],
    "month": [
        "månad"
    ],
    "week": [
        "veke"
    ],
    "day": [
        "dag"
    ],
    "hour": [
        "time"
    ],
    "minute": [
        "minutt"
    ],
    "second": [
        "sekund"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "i går"
        ],
        "0 day ago": [
            "i dag"
        ],
        "in 1 day": [
            "i morgon"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) år"
        ],
        "\\1 year ago": [
            "for (\\d+) år siden"
        ],
        "in \\1 month": [
            "om (\\d+) måned",
            "om (\\d+) måneder"
        ],
        "\\1 month ago": [
            "for (\\d+) måned siden",
            "for (\\d+) måneder siden"
        ],
        "in \\1 week": [
            "om (\\d+) uke",
            "om (\\d+) uker"
        ],
        "\\1 week ago": [
            "for (\\d+) uke siden",
            "for (\\d+) uker siden"
        ],
        "in \\1 day": [
            "om (\\d+) døgn"
        ],
        "\\1 day ago": [
            "for (\\d+) døgn siden"
        ],
        "in \\1 hour": [
            "om (\\d+) time",
            "om (\\d+) timer"
        ],
        "\\1 hour ago": [
            "for (\\d+) time siden",
            "for (\\d+) timer siden"
        ],
        "in \\1 minute": [
            "om (\\d+) minutt",
            "om (\\d+) minutter"
        ],
        "\\1 minute ago": [
            "for (\\d+) minutt siden",
            "for (\\d+) minutter siden"
        ],
        "in \\1 second": [
            "om (\\d+) sekund",
            "om (\\d+) sekunder"
        ],
        "\\1 second ago": [
            "for (\\d+) sekund siden",
            "for (\\d+) sekunder siden"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
