# -*- coding: utf-8 -*-
info = {
    "name": "ewo",
    "date_order": "DMY",
    "january": [
        "ngɔn osú",
        "ngo"
    ],
    "february": [
        "ngɔn bɛ̌",
        "ngb"
    ],
    "march": [
        "ngɔn lála",
        "ngl"
    ],
    "april": [
        "ngɔn nyina",
        "ngn"
    ],
    "may": [
        "ngɔn tána",
        "ngt"
    ],
    "june": [
        "ngɔn saməna",
        "ngs"
    ],
    "july": [
        "ngɔn zamgbála",
        "ngz"
    ],
    "august": [
        "ngɔn mwom",
        "ngm"
    ],
    "september": [
        "ngɔn ebulú",
        "nge"
    ],
    "october": [
        "ngɔn awóm",
        "nga"
    ],
    "november": [
        "ngɔn awóm ai dziá",
        "ngad"
    ],
    "december": [
        "ngɔn awóm ai bɛ̌",
        "ngab"
    ],
    "monday": [
        "mɔ́ndi",
        "mɔ́n"
    ],
    "tuesday": [
        "sɔ́ndɔ məlú mə́bɛ̌",
        "smb"
    ],
    "wednesday": [
        "sɔ́ndɔ məlú mə́lɛ́",
        "sml"
    ],
    "thursday": [
        "sɔ́ndɔ məlú mə́nyi",
        "smn"
    ],
    "friday": [
        "fúladé",
        "fúl"
    ],
    "saturday": [
        "séradé",
        "sér"
    ],
    "sunday": [
        "sɔ́ndɔ",
        "sɔ́n"
    ],
    "am": [
        "kíkíríg"
    ],
    "pm": [
        "ngəgógəle"
    ],
    "year": [
        "m̀bú"
    ],
    "month": [
        "ngɔn"
    ],
    "week": [
        "sɔ́ndɔ"
    ],
    "day": [
        "amǒs"
    ],
    "hour": [
        "awola"
    ],
    "minute": [
        "enútɛn"
    ],
    "second": [
        "akábəga"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "angogé"
        ],
        "0 day ago": [
            "aná"
        ],
        "in 1 day": [
            "okírí"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
