# -*- coding: utf-8 -*-
info = {
    "name": "sbp",
    "date_order": "DMY",
    "january": [
        "mupalangulwa",
        "mup"
    ],
    "february": [
        "mwitope",
        "mwi"
    ],
    "march": [
        "mushende",
        "msh"
    ],
    "april": [
        "munyi",
        "mun"
    ],
    "may": [
        "mushende magali",
        "mag"
    ],
    "june": [
        "mujimbi",
        "muj"
    ],
    "july": [
        "mushipepo",
        "msp"
    ],
    "august": [
        "mupuguto",
        "mpg"
    ],
    "september": [
        "munyense",
        "mye"
    ],
    "october": [
        "mokhu",
        "mok"
    ],
    "november": [
        "musongandembwe",
        "mus"
    ],
    "december": [
        "muhaano",
        "muh"
    ],
    "monday": [
        "jumatatu",
        "jtt"
    ],
    "tuesday": [
        "jumanne",
        "jnn"
    ],
    "wednesday": [
        "jumatano",
        "jtn"
    ],
    "thursday": [
        "alahamisi",
        "alh"
    ],
    "friday": [
        "ijumaa",
        "iju"
    ],
    "saturday": [
        "jumamosi",
        "jmo"
    ],
    "sunday": [
        "mulungu",
        "mul"
    ],
    "am": [
        "lwamilawu"
    ],
    "pm": [
        "pashamihe"
    ],
    "year": [
        "mwakha"
    ],
    "month": [
        "mwesi"
    ],
    "week": [
        "ilijuma"
    ],
    "day": [
        "lusiku"
    ],
    "hour": [
        "ilisala"
    ],
    "minute": [
        "idakika"
    ],
    "second": [
        "isekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "imehe"
        ],
        "0 day ago": [
            "ineng'uni"
        ],
        "in 1 day": [
            "pamulaawu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
