# -*- coding: utf-8 -*-
info = {
    "name": "sg",
    "date_order": "DMY",
    "january": [
        "nyenye",
        "nye"
    ],
    "february": [
        "fulundïgi",
        "ful"
    ],
    "march": [
        "mbängü",
        "mbä"
    ],
    "april": [
        "ngubùe",
        "ngu"
    ],
    "may": [
        "bêläwü",
        "bêl"
    ],
    "june": [
        "föndo",
        "fön"
    ],
    "july": [
        "lengua",
        "len"
    ],
    "august": [
        "kükürü",
        "kük"
    ],
    "september": [
        "mvuka",
        "mvu"
    ],
    "october": [
        "ngberere",
        "ngb"
    ],
    "november": [
        "nabändüru",
        "nab"
    ],
    "december": [
        "kakauka",
        "kak"
    ],
    "monday": [
        "bïkua-ûse",
        "bk2"
    ],
    "tuesday": [
        "bïkua-ptâ",
        "bk3"
    ],
    "wednesday": [
        "bïkua-usïö",
        "bk4"
    ],
    "thursday": [
        "bïkua-okü",
        "bk5"
    ],
    "friday": [
        "lâpôsö",
        "lâp"
    ],
    "saturday": [
        "lâyenga",
        "lây"
    ],
    "sunday": [
        "bikua-ôko",
        "bk1"
    ],
    "am": [
        "nd"
    ],
    "pm": [
        "lk"
    ],
    "year": [
        "ngû"
    ],
    "month": [
        "nze"
    ],
    "week": [
        "dimâsi"
    ],
    "day": [
        "lâ"
    ],
    "hour": [
        "ngbonga"
    ],
    "minute": [
        "ndurü ngbonga"
    ],
    "second": [
        "nzîna ngbonga"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "bîrï"
        ],
        "0 day ago": [
            "lâsô"
        ],
        "in 1 day": [
            "kêkerêke"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
