# -*- coding: utf-8 -*-
info = {
    "name": "hy",
    "date_order": "DMY",
    "january": [
        "հունվար",
        "հնվ",
        "հունվարի"
    ],
    "february": [
        "փետրվար",
        "փտվ",
        "փետրվարի"
    ],
    "march": [
        "մարտ",
        "մրտ",
        "մարտի"
    ],
    "april": [
        "ապրիլ",
        "ապր",
        "ապրիլի"
    ],
    "may": [
        "մայիս",
        "մյս",
        "մայիսի"
    ],
    "june": [
        "հունիս",
        "հնս",
        "հունիսի"
    ],
    "july": [
        "հուլիս",
        "հլս",
        "հուլիսի"
    ],
    "august": [
        "օգոստոս",
        "օգս",
        "օգոստոսի"
    ],
    "september": [
        "սեպտեմբեր",
        "սեպ",
        "սեպտեմբերի"
    ],
    "october": [
        "հոկտեմբեր",
        "հոկ",
        "հոկտեմբերի"
    ],
    "november": [
        "նոյեմբեր",
        "նոյ",
        "նոյեմբերի"
    ],
    "december": [
        "դեկտեմբեր",
        "դեկ",
        "դեկտեմբերի"
    ],
    "monday": [
        "երկուշաբթի",
        "երկ"
    ],
    "tuesday": [
        "երեքշաբթի",
        "երք"
    ],
    "wednesday": [
        "չորեքշաբթի",
        "չրք"
    ],
    "thursday": [
        "հինգշաբթի",
        "հնգ"
    ],
    "friday": [
        "ուրբաթ",
        "ուր"
    ],
    "saturday": [
        "շաբաթ",
        "շբթ"
    ],
    "sunday": [
        "կիրակի",
        "կիր"
    ],
    "am": [
        "am",
        "կա"
    ],
    "pm": [
        "pm",
        "կհ"
    ],
    "year": [
        "տարի",
        "տ"
    ],
    "month": [
        "ամիս",
        "ամս"
    ],
    "week": [
        "շաբաթ",
        "շաբ"
    ],
    "day": [
        "օր"
    ],
    "hour": [
        "ժամ",
        "ժ"
    ],
    "minute": [
        "րոպե",
        "ր"
    ],
    "second": [
        "վայրկյան",
        "վ"
    ],
    "relative-type": {
        "1 year ago": [
            "նախորդ տարի"
        ],
        "0 year ago": [
            "այս տարի"
        ],
        "in 1 year": [
            "հաջորդ տարի"
        ],
        "1 month ago": [
            "նախորդ ամիս",
            "անցյալ ամիս"
        ],
        "0 month ago": [
            "այս ամիս"
        ],
        "in 1 month": [
            "հաջորդ ամիս"
        ],
        "1 week ago": [
            "նախորդ շաբաթ"
        ],
        "0 week ago": [
            "այս շաբաթ"
        ],
        "in 1 week": [
            "հաջորդ շաբաթ"
        ],
        "1 day ago": [
            "երեկ"
        ],
        "0 day ago": [
            "այսօր"
        ],
        "in 1 day": [
            "վաղը"
        ],
        "0 hour ago": [
            "այս ժամին"
        ],
        "0 minute ago": [
            "այս րոպեին"
        ],
        "0 second ago": [
            "այժմ"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) տարուց"
        ],
        "\\1 year ago": [
            "(\\d+) տարի առաջ",
            "(\\d+) տ առաջ"
        ],
        "in \\1 month": [
            "(\\d+) ամսից"
        ],
        "\\1 month ago": [
            "(\\d+) ամիս առաջ"
        ],
        "in \\1 week": [
            "(\\d+) շաբաթից",
            "(\\d+) շաբ-ից",
            "(\\d+) շաբ անց"
        ],
        "\\1 week ago": [
            "(\\d+) շաբաթ առաջ",
            "(\\d+) շաբ առաջ"
        ],
        "in \\1 day": [
            "(\\d+) օրից"
        ],
        "\\1 day ago": [
            "(\\d+) օր առաջ"
        ],
        "in \\1 hour": [
            "(\\d+) ժամից",
            "(\\d+) ժ-ից"
        ],
        "\\1 hour ago": [
            "(\\d+) ժամ առաջ",
            "(\\d+) ժ առաջ"
        ],
        "in \\1 minute": [
            "(\\d+) րոպեից",
            "(\\d+) ր-ից"
        ],
        "\\1 minute ago": [
            "(\\d+) րոպե առաջ",
            "(\\d+) ր առաջ"
        ],
        "in \\1 second": [
            "(\\d+) վայրկյանից",
            "(\\d+) վրկ-ից",
            "(\\d+) վ-ից"
        ],
        "\\1 second ago": [
            "(\\d+) վայրկյան առաջ",
            "(\\d+) վրկ առաջ",
            "(\\d+) վ առաջ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
