# -*- coding: utf-8 -*-
info = {
    "name": "fil",
    "date_order": "MDY",
    "january": [
        "enero",
        "ene"
    ],
    "february": [
        "pebrero",
        "peb"
    ],
    "march": [
        "marso",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "mayo",
        "may"
    ],
    "june": [
        "hunyo",
        "hun"
    ],
    "july": [
        "hulyo",
        "hul"
    ],
    "august": [
        "agosto",
        "ago"
    ],
    "september": [
        "setyembre",
        "set"
    ],
    "october": [
        "oktubre",
        "okt"
    ],
    "november": [
        "nobyembre",
        "nob"
    ],
    "december": [
        "disyembre",
        "dis"
    ],
    "monday": [
        "lunes",
        "lun"
    ],
    "tuesday": [
        "martes",
        "mar"
    ],
    "wednesday": [
        "miyerkules",
        "miy"
    ],
    "thursday": [
        "huwebes",
        "huw"
    ],
    "friday": [
        "biyernes",
        "biy"
    ],
    "saturday": [
        "sabado",
        "sab"
    ],
    "sunday": [
        "linggo",
        "lin"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "taon"
    ],
    "month": [
        "buwan"
    ],
    "week": [
        "linggo"
    ],
    "day": [
        "araw"
    ],
    "hour": [
        "oras"
    ],
    "minute": [
        "minuto",
        "min"
    ],
    "second": [
        "segundo",
        "seg"
    ],
    "relative-type": {
        "1 year ago": [
            "nakaraang taon"
        ],
        "0 year ago": [
            "ngayong taon"
        ],
        "in 1 year": [
            "susunod na taon"
        ],
        "1 month ago": [
            "nakaraang buwan"
        ],
        "0 month ago": [
            "ngayong buwan"
        ],
        "in 1 month": [
            "susunod na buwan"
        ],
        "1 week ago": [
            "nakalipas na linggo",
            "nakaraang linggo"
        ],
        "0 week ago": [
            "sa linggong ito",
            "ngayong linggo"
        ],
        "in 1 week": [
            "susunod na linggo"
        ],
        "1 day ago": [
            "kahapon"
        ],
        "0 day ago": [
            "ngayong araw"
        ],
        "in 1 day": [
            "bukas"
        ],
        "0 hour ago": [
            "ngayong oras"
        ],
        "0 minute ago": [
            "sa minutong ito"
        ],
        "0 second ago": [
            "ngayon"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "sa (\\d+) taon"
        ],
        "\\1 year ago": [
            "(\\d+) taon ang nakalipas"
        ],
        "in \\1 month": [
            "sa (\\d+) buwan"
        ],
        "\\1 month ago": [
            "(\\d+) buwan ang nakalipas"
        ],
        "in \\1 week": [
            "sa (\\d+) linggo"
        ],
        "\\1 week ago": [
            "(\\d+) linggo ang nakalipas"
        ],
        "in \\1 day": [
            "sa (\\d+) araw"
        ],
        "\\1 day ago": [
            "(\\d+) araw ang nakalipas"
        ],
        "in \\1 hour": [
            "sa (\\d+) oras"
        ],
        "\\1 hour ago": [
            "(\\d+) oras ang nakalipas",
            "(\\d+) oras nakalipas"
        ],
        "in \\1 minute": [
            "sa (\\d+) minuto",
            "sa (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) minuto ang nakalipas",
            "(\\d+) min ang nakalipas"
        ],
        "in \\1 second": [
            "sa (\\d+) segundo",
            "sa (\\d+) seg"
        ],
        "\\1 second ago": [
            "(\\d+) segundo ang nakalipas",
            "(\\d+) seg ang nakalipas",
            "(\\d+) seg nakalipas"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
