# -*- coding: utf-8 -*-
info = {
    "%%aja": {
        "0": "ная;",
        "(1, 'inf')": "'а =%spellout-ordinal-feminine=;"
    },
    "%%fractions-feminine": {
        "(10, 99)": "<%spellout-cardinal-feminine< $(cardinal,one{десятая}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine< $(cardinal,one{сотая}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысячная}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine< $(cardinal,one{десятитысячная}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{стотысячная}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine< $(cardinal,one{миллионная}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine< $(cardinal,one{десятимиллионная}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{стомиллионная}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{миллиардная}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{десятимиллиардная}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine< $(cardinal,one{стомиллиардная}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-ablative": {
        "(10, 99)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятой}other{десятыми})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{сотой}other{сотыми})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячной}other{тысячными})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятитысячной}other{десятитысячными})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{стотысячной}other{стотысячными})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{миллионной}other{миллионными})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятимиллионной}other{десятимиллионными})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{стомиллионной}other{стомиллионными})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{миллиардной}other{миллиардными})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{десятимиллиардной}other{десятимиллиардными})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{стомиллиардной}other{стомиллиардными})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-accusative": {
        "(10, 99)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятую}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{сотую}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячную}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятитысячную}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{стотысячную}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{миллионную}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятимиллионную}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{стомиллионную}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{миллиардную}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{десятимиллиардную}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{стомиллиардную}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-dative": {
        "(10, 99)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятой}other{десятым})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{сотой}other{сотым})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысячной}other{тысячным})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятитысячной}other{десятитысячным})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{стотысячной}other{стотысячным})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{миллионной}other{миллионным})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятимиллионной}other{десятимиллионным})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{стомиллионной}other{стомиллионным})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{миллиардной}other{миллиардным})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{десятимиллиардной}other{десятимиллиардным})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{стомиллиардной}other{стомиллиардным})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-genitive": {
        "(10, 99)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятой}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{сотой}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячной}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятитысячной}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{стотысячной}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{миллионной}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятимиллионной}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{стомиллионной}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{миллиардной}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{десятимиллиардной}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{стомиллиардной}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%fractions-feminine-locative": {
        "(10, 99)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятой}other{десятых})$;",
        "(100, 999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{сотой}other{сотых})$;",
        "(1000, 9999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысячной}other{тысячных})$;",
        "(10000, 99999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятитысячной}other{десятитысячных})$;",
        "(100000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{стотысячной}other{стотысячных})$;",
        "(1000000, 9999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{миллионной}other{миллионных})$;",
        "(10000000, 99999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятимиллионной}other{десятимиллионных})$;",
        "(100000000, 999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{стомиллионной}other{стомиллионных})$;",
        "(1000000000, 9999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{миллиардной}other{миллиардных})$;",
        "(10000000000, 99999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{десятимиллиардной}other{десятимиллиардных})$;",
        "(100000000000, 999999999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{стомиллиардной}other{стомиллиардных})$;",
        "(1000000000000, 'inf')": "<0<;"
    },
    "%%oe": {
        "0": "ное;",
        "(1, 'inf')": "'а =%spellout-ordinal-neuter=;"
    },
    "%%ogo": {
        "0": "ного;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-genitive=;"
    },
    "%%oj": {
        "0": "ной;",
        "(1, 'inf')": "'а =%spellout-ordinal-feminine-genitive=;"
    },
    "%%om": {
        "0": "ном;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-locative=;"
    },
    "%%omu": {
        "0": "ному;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-dative=;"
    },
    "%%thousandsprefixconjoined": {
        "0": "=%spellout-cardinal-feminine-genitive=;",
        "1": "одно;",
        "(2, 20)": "=%spellout-cardinal-feminine-genitive=;",
        "21": "двадцатиодно;",
        "(22, 29)": "двадцати[>>];",
        "30": "тридцати;",
        "31": "тридцатиодно;",
        "(32, 39)": "тридцати[>>];",
        "40": "сорока;",
        "41": "сорокаодно;",
        "(42, 49)": "сорока[>>];",
        "50": "пятидесяти;",
        "51": "пятидесятиодно;",
        "(52, 59)": "пятидесяти[>>];",
        "60": "шестидесяти;",
        "61": "шестидесятиодно;",
        "(62, 69)": "шестидесяти[>>];",
        "70": "семидесяти;",
        "71": "семидесятиодно;",
        "(72, 79)": "семидесяти[>>];",
        "80": "восьмидесяти;",
        "81": "восьмидесятиодно;",
        "(82, 89)": "восьмидесяти[>>];",
        "90": "=%spellout-cardinal-feminine=;",
        "91": "девяностоодно;",
        "(92, 99)": "девяносто[>>];",
        "(100, 199)": "сто[>>];",
        "(200, 'inf')": "<%spellout-cardinal-feminine-genitive<сот[>>];"
    },
    "%%thousandsprefixseparate": {
        "(0, 'inf')": "=%spellout-cardinal-feminine= ;"
    },
    "%%uju": {
        "0": "ную;",
        "(1, 'inf')": "'а =%spellout-ordinal-feminine-accusative=;"
    },
    "%%ye": {
        "0": "ные;",
        "(1, 'inf')": "'а =%spellout-ordinal-plural=;"
    },
    "%%yh": {
        "0": "ных;",
        "(1, 'inf')": "'а =%spellout-ordinal-plural-genitive=;"
    },
    "%%yj": {
        "0": "ный;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine=;"
    },
    "%%ym": {
        "0": "ным;",
        "(1, 'inf')": "'а =%spellout-ordinal-masculine-ablative=;"
    },
    "%%ymi": {
        "0": "ными;",
        "(1, 'inf')": "'а =%spellout-ordinal-plural-ablative=;"
    },
    "%spellout-cardinal-feminine": {
        "0": "ноль;",
        "1": "одна;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-ablative": {
        "0": "нулем;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-ablative=;",
        "(20, 29)": "двадцатью[ >>];",
        "(30, 39)": "тридцатью[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятьюдесятью[ >>];",
        "(60, 69)": "шестьюдесятью[ >>];",
        "(70, 79)": "семьюдесятью[ >>];",
        "(80, 89)": "восемьюдесятью[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-ablative<стами[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячей}other{тысячами})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллионом}other{миллионами})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллиардом}other{миллиардами})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{триллионом}other{триллионами})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{квадриллионом}other{квадриллионами})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-accusative": {
        "0": "ноль;",
        "1": "одну;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine-accusative=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-dative": {
        "0": "нолю;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-dative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-dative<стам[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысяче}other{тысячам})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиону}other{миллионам})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиарду}other{миллиардам})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{триллиону}other{триллионам})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{квадриллиону}other{квадриллионам})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-genitive": {
        "0": "ноля;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-genitive=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-genitive<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-feminine-locative": {
        "0": "нуле;",
        "1": "одной;",
        "(2, 19)": "=%spellout-cardinal-masculine-locative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine": {
        "0": "ноль;",
        "1": "один;",
        "2": "два;",
        "3": "три;",
        "4": "четыре;",
        "5": "пять;",
        "6": "шесть;",
        "7": "семь;",
        "8": "восемь;",
        "9": "девять;",
        "10": "десять;",
        "11": "одиннадцать;",
        "12": "двенадцать;",
        "13": "тринадцать;",
        "14": "четырнадцать;",
        "15": "пятнадцать;",
        "16": "шестнадцать;",
        "17": "семнадцать;",
        "18": "восемнадцать;",
        "19": "девятнадцать;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-ablative": {
        "0": "нулем;",
        "1": "одним;",
        "2": "двумя;",
        "3": "тремя;",
        "4": "четырьмя;",
        "5": "пятью;",
        "6": "шестью;",
        "7": "семью;",
        "8": "восемью;",
        "9": "девятью;",
        "10": "десятью;",
        "11": "одиннадцатью;",
        "12": "двенадцатью;",
        "13": "тринадцатью;",
        "14": "четырнадцатью;",
        "15": "пятнадцатью;",
        "16": "шестнадцатью;",
        "17": "семнадцатью;",
        "18": "восемнадцатью;",
        "19": "девятнадцатью;",
        "(20, 29)": "двадцатью[ >>];",
        "(30, 39)": "тридцатью[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятьюдесятью[ >>];",
        "(60, 69)": "шестьюдесятью[ >>];",
        "(70, 79)": "семьюдесятью[ >>];",
        "(80, 89)": "восемьюдесятью[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-ablative<стами[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячей}other{тысячами})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллионом}other{миллионами})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллиардом}other{миллиардами})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{триллионом}other{триллионами})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{квадриллионом}other{квадриллионами})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-accusative": {
        "0": "ноль;",
        "1": "один;",
        "2": "два;",
        "3": "три;",
        "4": "четыре;",
        "5": "пять;",
        "6": "шесть;",
        "7": "семь;",
        "8": "восемь;",
        "9": "девять;",
        "10": "десять;",
        "11": "одиннадцать;",
        "12": "двенадцать;",
        "13": "тринадцать;",
        "14": "четырнадцать;",
        "15": "пятнадцать;",
        "16": "шестнадцать;",
        "17": "семнадцать;",
        "18": "восемнадцать;",
        "19": "девятнадцать;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-dative": {
        "0": "нолю;",
        "1": "одному;",
        "2": "двум;",
        "3": "трем;",
        "4": "четырем;",
        "5": "пяти;",
        "6": "шести;",
        "7": "семи;",
        "8": "восьми;",
        "9": "девяти;",
        "10": "десяти;",
        "11": "одиннадцати;",
        "12": "двенадцати;",
        "13": "тринадцати;",
        "14": "четырнадцати;",
        "15": "пятнадцати;",
        "16": "шестнадцати;",
        "17": "семнадцати;",
        "18": "восемнадцати;",
        "19": "девятнадцати;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-dative<стам[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысяче}other{тысячам})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиону}other{миллионам})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиарду}other{миллиардам})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{триллиону}other{триллионам})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{квадриллиону}other{квадриллионам})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-genitive": {
        "0": "ноля;",
        "1": "одного;",
        "2": "двух;",
        "3": "трех;",
        "4": "четырех;",
        "5": "пяти;",
        "6": "шести;",
        "7": "семи;",
        "8": "восьми;",
        "9": "девяти;",
        "10": "десяти;",
        "11": "одиннадцати;",
        "12": "двенадцати;",
        "13": "тринадцати;",
        "14": "четырнадцати;",
        "15": "пятнадцати;",
        "16": "шестнадцати;",
        "17": "семнадцати;",
        "18": "восемнадцати;",
        "19": "девятнадцати;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-genitive<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine-locative": {
        "0": "нуле;",
        "1": "одном;",
        "2": "двух;",
        "3": "трех;",
        "4": "четырех;",
        "5": "пяти;",
        "6": "шести;",
        "7": "семи;",
        "8": "восьми;",
        "9": "девяти;",
        "10": "десяти;",
        "11": "одиннадцати;",
        "12": "двенадцати;",
        "13": "тринадцати;",
        "14": "четырнадцати;",
        "15": "пятнадцати;",
        "16": "шестнадцати;",
        "17": "семнадцати;",
        "18": "восемнадцати;",
        "19": "девятнадцати;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter": {
        "0": "ноль;",
        "1": "одно;",
        "(2, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter-ablative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-ablative=;"
    },
    "%spellout-cardinal-neuter-accusative": {
        "0": "ноль;",
        "1": "одно;",
        "(2, 19)": "=%spellout-cardinal-masculine-accusative=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-neuter-dative": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-dative=;"
    },
    "%spellout-cardinal-neuter-genitive": {
        "(0, 'inf')": "=%spellout-cardinal-masculine-genitive=;"
    },
    "%spellout-cardinal-neuter-locative": {
        "0": "нуле;",
        "1": "одном;",
        "(2, 19)": "=%spellout-cardinal-masculine-locative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural": {
        "0": "ноль;",
        "1": "одни;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine< $(cardinal,one{тысяча}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-ablative": {
        "0": "нулем;",
        "1": "одними;",
        "(2, 19)": "=%spellout-cardinal-masculine-ablative=;",
        "(20, 29)": "двадцатью[ >>];",
        "(30, 39)": "тридцатью[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятьюдесятью[ >>];",
        "(60, 69)": "шестьюдесятью[ >>];",
        "(70, 79)": "семьюдесятью[ >>];",
        "(80, 89)": "восемьюдесятью[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-ablative<стами[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-ablative< $(cardinal,one{тысячей}other{тысячами})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллионом}other{миллионами})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{миллиардом}other{миллиардами})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{триллионом}other{триллионами})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-ablative< $(cardinal,one{квадриллионом}other{квадриллионами})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-accusative": {
        "0": "ноль;",
        "1": "одни;",
        "2": "две;",
        "(3, 19)": "=%spellout-cardinal-masculine-accusative=;",
        "(20, 29)": "двадцать[ >>];",
        "(30, 39)": "тридцать[ >>];",
        "(40, 49)": "сорок[ >>];",
        "(50, 59)": "пятьдесят[ >>];",
        "(60, 69)": "шестьдесят[ >>];",
        "(70, 79)": "семьдесят[ >>];",
        "(80, 89)": "восемьдесят[ >>];",
        "(90, 99)": "девяносто[ >>];",
        "(100, 199)": "сто[ >>];",
        "(200, 299)": "<%spellout-cardinal-feminine-accusative<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine-accusative<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine-accusative<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-accusative< $(cardinal,one{тысячу}few{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллион}few{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-accusative< $(cardinal,one{миллиард}few{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{триллион}few{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< $(cardinal,one{квадриллион}few{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-dative": {
        "0": "нолю;",
        "1": "одним;",
        "(2, 19)": "=%spellout-cardinal-masculine-dative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-dative<стам[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-dative< $(cardinal,one{тысяче}other{тысячам})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиону}other{миллионам})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{миллиарду}other{миллиардам})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{триллиону}other{триллионам})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-dative< $(cardinal,one{квадриллиону}other{квадриллионам})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-genitive": {
        "0": "ноля;",
        "1": "одних;",
        "(2, 19)": "=%spellout-cardinal-masculine-genitive=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-genitive<сот[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-genitive< $(cardinal,one{тысячи}other{тысяч})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиона}other{миллионов})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{миллиарда}other{миллиардов})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{триллиона}other{триллионов})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-genitive< $(cardinal,one{квадриллиона}other{квадриллионов})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-plural-locative": {
        "0": "нуле;",
        "1": "одних;",
        "(2, 19)": "=%spellout-cardinal-masculine-locative=;",
        "(20, 29)": "двадцати[ >>];",
        "(30, 39)": "тридцати[ >>];",
        "(40, 49)": "сорока[ >>];",
        "(50, 59)": "пятидесяти[ >>];",
        "(60, 69)": "шестидесяти[ >>];",
        "(70, 79)": "семидесяти[ >>];",
        "(80, 89)": "восьмидесяти[ >>];",
        "(90, 99)": "девяноста[ >>];",
        "(100, 199)": "ста[ >>];",
        "(200, 999)": "<%spellout-cardinal-feminine-locative<стах[ >>];",
        "(1000, 999999)": "<%spellout-cardinal-feminine-locative< $(cardinal,one{тысяче}other{тысячах})$[ >>];",
        "(1000000, 999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллионе}other{миллионах})$[ >>];",
        "(1000000000, 999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{миллиарде}other{миллиардах})$[ >>];",
        "(1000000000000, 999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{триллионе}other{триллионах})$[ >>];",
        "(1000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine-locative< $(cardinal,one{квадриллионе}other{квадриллионах})$[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-numbering": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-numbering-year": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-genitive=;"
    },
    "%spellout-ordinal-feminine": {
        "0": "ноль;",
        "1": "первая;",
        "2": "вторая;",
        "3": "третья;",
        "4": "четвертая;",
        "5": "пятая;",
        "6": "шестая;",
        "7": "седьмая;",
        "8": "восьмая;",
        "9": "девятая;",
        "10": "десятая;",
        "11": "одиннадцатая;",
        "12": "двенадцатая;",
        "13": "тринадцатая;",
        "14": "четырнадцатая;",
        "15": "пятнадцатая;",
        "16": "шестнадцатая;",
        "17": "семнадцатая;",
        "18": "восемнадцатая;",
        "19": "девятнадцатая;",
        "20": "двадцатая;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатая;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковая;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятая;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятая;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятая;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятая;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностая;",
        "(91, 99)": "девяносто >>;",
        "100": "сотая;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%aja>;",
        "(1001, 21000)": "одна тысяч>%%aja>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-feminine-ablative": {
        "(0, 'inf')": "=%spellout-ordinal-feminine-genitive=;"
    },
    "%spellout-ordinal-feminine-accusative": {
        "0": "нулевую;",
        "1": "первую;",
        "2": "вторую;",
        "3": "третью;",
        "4": "четвертую;",
        "5": "пятую;",
        "6": "шестую;",
        "7": "седьмую;",
        "8": "восьмую;",
        "9": "девятую;",
        "10": "десятую;",
        "11": "одиннадцатую;",
        "12": "двенадцатую;",
        "13": "тринадцатую;",
        "14": "четырнадцатую;",
        "15": "пятнадцатую;",
        "16": "шестнадцатую;",
        "17": "семнадцатую;",
        "18": "восемнадцатую;",
        "19": "девятнадцатую;",
        "20": "двадцатую;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатую;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковую;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятую;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятую;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятую;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятую;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностую;",
        "(91, 99)": "девяносто >>;",
        "100": "сотую;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%uju>;",
        "(1001, 21000)": "одна тысяч>%%uju>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-feminine-dative": {
        "(0, 'inf')": "=%spellout-ordinal-feminine-genitive=;"
    },
    "%spellout-ordinal-feminine-genitive": {
        "0": "нулевой;",
        "1": "первой;",
        "2": "второй;",
        "3": "третьей;",
        "4": "четвертой;",
        "5": "пятой;",
        "6": "шестой;",
        "7": "седьмой;",
        "8": "восьмой;",
        "9": "девятой;",
        "10": "десятой;",
        "11": "одиннадцатой;",
        "12": "двенадцатой;",
        "13": "тринадцатой;",
        "14": "четырнадцатой;",
        "15": "пятнадцатой;",
        "16": "шестнадцатой;",
        "17": "семнадцатой;",
        "18": "восемнадцатой;",
        "19": "девятнадцатой;",
        "20": "двадцатой;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатой;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятой;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятой;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятой;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятой;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностой;",
        "(91, 99)": "девяносто >>;",
        "100": "сотой;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%oj>;",
        "(1001, 21000)": "одна тысяч>%%oj>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-feminine-locative": {
        "(0, 'inf')": "=%spellout-ordinal-feminine-genitive=;"
    },
    "%spellout-ordinal-masculine": {
        "0": "нулевой;",
        "1": "первый;",
        "2": "второй;",
        "3": "третий;",
        "4": "четвертый;",
        "5": "пятый;",
        "6": "шестой;",
        "7": "седьмой;",
        "8": "восьмой;",
        "9": "девятый;",
        "10": "десятый;",
        "11": "одиннадцатый;",
        "12": "двенадцатый;",
        "13": "тринадцатый;",
        "14": "четырнадцатый;",
        "15": "пятнадцатый;",
        "16": "шестнадцатый;",
        "17": "семнадцатый;",
        "18": "восемнадцатый;",
        "19": "девятнадцатый;",
        "20": "двадцатый;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатый;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятый;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятый;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятый;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятый;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностый;",
        "(91, 99)": "девяносто >>;",
        "100": "сотый;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%yj>;",
        "(1001, 21000)": "одна тысяч>%%yj>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-ablative": {
        "0": "нулевым;",
        "1": "первым;",
        "2": "вторым;",
        "3": "третьим;",
        "4": "четвертым;",
        "5": "пятым;",
        "6": "шестым;",
        "7": "седьмым;",
        "8": "восьмым;",
        "9": "девятым;",
        "10": "десятым;",
        "11": "одиннадцатым;",
        "12": "двенадцатым;",
        "13": "тринадцатым;",
        "14": "четырнадцатым;",
        "15": "пятнадцатым;",
        "16": "шестнадцатым;",
        "17": "семнадцатым;",
        "18": "восемнадцатым;",
        "19": "девятнадцатым;",
        "20": "двадцатым;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатым;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковым;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятым;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятым;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятым;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятым;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностым;",
        "(91, 99)": "девяносто >>;",
        "100": "сотым;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ym>;",
        "(1001, 21000)": "одна тысяч>%%ym>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-accusative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine=;"
    },
    "%spellout-ordinal-masculine-dative": {
        "0": "нулевому;",
        "1": "первому;",
        "2": "второму;",
        "3": "третьому;",
        "4": "четвертому;",
        "5": "пятому;",
        "6": "шестому;",
        "7": "седьмому;",
        "8": "восьмому;",
        "9": "девятому;",
        "10": "десятому;",
        "11": "одиннадцатому;",
        "12": "двенадцатому;",
        "13": "тринадцатому;",
        "14": "четырнадцатому;",
        "15": "пятнадцатому;",
        "16": "шестнадцатому;",
        "17": "семнадцатому;",
        "18": "восемнадцатому;",
        "19": "девятнадцатому;",
        "20": "двадцатому;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатому;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковому;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятому;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятому;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятому;",
        "(71, 79)": "семьдесят >>;",
        "80": "восемьдесятому;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностому;",
        "(91, 99)": "девяносто >>;",
        "100": "сотому;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%omu>;",
        "(1001, 21000)": "одна тысяч>%%omu>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-genitive": {
        "0": "нулевого;",
        "1": "первого;",
        "2": "второго;",
        "3": "третьего;",
        "4": "четвертого;",
        "5": "пятого;",
        "6": "шестого;",
        "7": "седьмого;",
        "8": "восьмого;",
        "9": "девятого;",
        "10": "десятого;",
        "11": "одиннадцатого;",
        "12": "двенадцатого;",
        "13": "тринадцатого;",
        "14": "четырнадцатого;",
        "15": "пятнадцатого;",
        "16": "шестнадцатого;",
        "17": "семнадцатого;",
        "18": "восемнадцатого;",
        "19": "девятнадцатого;",
        "20": "двадцатого;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатого;",
        "(31, 39)": "тридцать >>;",
        "40": "сорокового;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятого;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятого;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятого;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятого;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностого;",
        "(91, 99)": "девяносто >>;",
        "100": "сотого;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ogo>;",
        "(1001, 21000)": "одна тысяч>%%ogo>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-masculine-locative": {
        "0": "нулевом;",
        "1": "первом;",
        "2": "втором;",
        "3": "третьем;",
        "4": "четвертом;",
        "5": "пятом;",
        "6": "шестом;",
        "7": "седьмом;",
        "8": "восьмом;",
        "9": "девятом;",
        "10": "десятом;",
        "11": "одиннадцатом;",
        "12": "двенадцатом;",
        "13": "тринадцатом;",
        "14": "четырнадцатом;",
        "15": "пятнадцатом;",
        "16": "шестнадцатом;",
        "17": "семнадцатом;",
        "18": "восемнадцатом;",
        "19": "девятнадцатом;",
        "20": "двадцатом;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатом;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятом;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятом;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятом;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятом;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностом;",
        "(91, 99)": "девяносто >>;",
        "100": "сотом;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%om>;",
        "(1001, 21000)": "одна тысяч>%%om>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-neuter": {
        "0": "нулевое;",
        "1": "первое;",
        "2": "второе;",
        "3": "третье;",
        "4": "четвертое;",
        "5": "пятое;",
        "6": "шестое;",
        "7": "седьмое;",
        "8": "восьмое;",
        "9": "девятое;",
        "10": "десятое;",
        "11": "одиннадцатое;",
        "12": "двенадцатое;",
        "13": "тринадцатое;",
        "14": "четырнадцатое;",
        "15": "пятнадцатое;",
        "16": "шестнадцатое;",
        "17": "семнадцатое;",
        "18": "восемнадцатое;",
        "19": "девятнадцатое;",
        "20": "двадцатое;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатое;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковое;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятое;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятое;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятое;",
        "(71, 79)": "семьдесят >>;",
        "80": "восемьдесятое;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностое;",
        "(91, 99)": "девяносто >>;",
        "100": "сотое;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%oe>;",
        "(1001, 21000)": "одна тысяч>%%oe>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-neuter-ablative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-ablative=;"
    },
    "%spellout-ordinal-neuter-accusative": {
        "(0, 'inf')": "=%spellout-ordinal-neuter=;"
    },
    "%spellout-ordinal-neuter-dative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-dative=;"
    },
    "%spellout-ordinal-neuter-genitive": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-genitive=;"
    },
    "%spellout-ordinal-neuter-locative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-locative=;"
    },
    "%spellout-ordinal-plural": {
        "0": "нулевые;",
        "1": "первые;",
        "2": "вторые;",
        "3": "третьи;",
        "4": "четвертые;",
        "5": "пятые;",
        "6": "шестые;",
        "7": "седьмые;",
        "8": "восьмые;",
        "9": "девятые;",
        "10": "десятые;",
        "11": "одиннадцатые;",
        "12": "двенадцатые;",
        "13": "тринадцатые;",
        "14": "четырнадцатые;",
        "15": "пятнадцатые;",
        "16": "шестнадцатые;",
        "17": "семнадцатые;",
        "18": "восемнадцатые;",
        "19": "девятнадцатые;",
        "20": "двадцатые;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатые;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковые;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятые;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятые;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятые;",
        "(71, 79)": "семьдесят >>;",
        "80": "восемьдесятые;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностые;",
        "(91, 99)": "девяносто >>;",
        "100": "сотые;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ye>;",
        "(1001, 21000)": "одна тысяч>%%ye>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-plural-ablative": {
        "0": "нулевыми;",
        "1": "первыми;",
        "2": "вторыми;",
        "3": "третьими;",
        "4": "четвертыми;",
        "5": "пятыми;",
        "6": "шестыми;",
        "7": "седьмыми;",
        "8": "восьмыми;",
        "9": "девятыми;",
        "10": "десятыми;",
        "11": "одиннадцатыми;",
        "12": "двенадцатыми;",
        "13": "тринадцатыми;",
        "14": "четырнадцатыми;",
        "15": "пятнадцатыми;",
        "16": "шестнадцатыми;",
        "17": "семнадцатыми;",
        "18": "восемнадцатыми;",
        "19": "девятнадцатыми;",
        "20": "двадцатыми;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатыми;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковой;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятыми;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятыми;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятыми;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятыми;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностыми;",
        "(91, 99)": "девяносто >>;",
        "100": "сотыми;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%ymi>;",
        "(1001, 21000)": "одна тысяч>%%ymi>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-plural-accusative": {
        "(0, 'inf')": "=%spellout-ordinal-plural=;"
    },
    "%spellout-ordinal-plural-dative": {
        "(0, 'inf')": "=%spellout-ordinal-masculine-ablative=;"
    },
    "%spellout-ordinal-plural-genitive": {
        "0": "нулевых;",
        "1": "первых;",
        "2": "вторых;",
        "3": "третьих;",
        "4": "четвертых;",
        "5": "пятых;",
        "6": "шестых;",
        "7": "седьмых;",
        "8": "восьмых;",
        "9": "девятых;",
        "10": "десятых;",
        "11": "одиннадцатых;",
        "12": "двенадцатых;",
        "13": "тринадцатых;",
        "14": "четырнадцатых;",
        "15": "пятнадцатых;",
        "16": "шестнадцатых;",
        "17": "семнадцатых;",
        "18": "восемнадцатых;",
        "19": "девятнадцатых;",
        "20": "двадцатых;",
        "(21, 29)": "двадцать >>;",
        "30": "тридцатых;",
        "(31, 39)": "тридцать >>;",
        "40": "сороковых;",
        "(41, 49)": "сорок >>;",
        "50": "пятидесятых;",
        "(51, 59)": "пятьдесят >>;",
        "60": "шестидесятых;",
        "(61, 69)": "шестьдесят >>;",
        "70": "семидесятых;",
        "(71, 79)": "семьдесят >>;",
        "80": "восьмидесятых;",
        "(81, 89)": "восемьдесят >>;",
        "90": "девяностых;",
        "(91, 99)": "девяносто >>;",
        "100": "сотых;",
        "(101, 199)": "сто >>;",
        "(200, 299)": "<%spellout-cardinal-feminine<сти[ >>];",
        "(300, 499)": "<%spellout-cardinal-feminine<ста[ >>];",
        "(500, 999)": "<%spellout-cardinal-feminine<сот[ >>];",
        "1000": "тысяч>%%yh>;",
        "(1001, 21000)": "одна тысяч>%%yh>;",
        "(21001, 'inf')": "=0=.;"
    },
    "%spellout-ordinal-plural-locative": {
        "(0, 'inf')": "=%spellout-ordinal-plural-genitive=;"
    }
}
