# -*- coding: utf-8 -*-
info = {
    "name": "az-Latn",
    "date_order": "DMY",
    "january": [
        "yanvar",
        "yan"
    ],
    "february": [
        "fevral",
        "fev"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "aprel",
        "apr"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyun",
        "iyn"
    ],
    "july": [
        "iyul",
        "iyl"
    ],
    "august": [
        "avqust",
        "avq"
    ],
    "september": [
        "sentyabr",
        "sen"
    ],
    "october": [
        "oktyabr",
        "okt"
    ],
    "november": [
        "noyabr",
        "noy"
    ],
    "december": [
        "dekabr",
        "dek"
    ],
    "monday": [
        "bazar ertəsi",
        "be"
    ],
    "tuesday": [
        "çərşənbə axşamı",
        "ça"
    ],
    "wednesday": [
        "çərşənbə",
        "ç"
    ],
    "thursday": [
        "cümə axşamı",
        "ca"
    ],
    "friday": [
        "cümə",
        "c"
    ],
    "saturday": [
        "şənbə",
        "ş"
    ],
    "sunday": [
        "bazar",
        "b"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "il"
    ],
    "month": [
        "ay"
    ],
    "week": [
        "həftə"
    ],
    "day": [
        "gün"
    ],
    "hour": [
        "saat"
    ],
    "minute": [
        "dəqiqə",
        "dəq"
    ],
    "second": [
        "saniyə",
        "san"
    ],
    "relative-type": {
        "1 year ago": [
            "keçən il"
        ],
        "0 year ago": [
            "bu il"
        ],
        "in 1 year": [
            "gələn il"
        ],
        "1 month ago": [
            "keçən ay"
        ],
        "0 month ago": [
            "bu ay"
        ],
        "in 1 month": [
            "gələn ay"
        ],
        "1 week ago": [
            "keçən həftə"
        ],
        "0 week ago": [
            "bu həftə"
        ],
        "in 1 week": [
            "gələn həftə"
        ],
        "1 day ago": [
            "dünən"
        ],
        "0 day ago": [
            "bu gün"
        ],
        "in 1 day": [
            "sabah"
        ],
        "0 hour ago": [
            "bu saat"
        ],
        "0 minute ago": [
            "bu dəqiqə"
        ],
        "0 second ago": [
            "indi"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) il ərzində"
        ],
        "\\1 year ago": [
            "(\\d+) il öncə"
        ],
        "in \\1 month": [
            "(\\d+) ay ərzində"
        ],
        "\\1 month ago": [
            "(\\d+) ay öncə"
        ],
        "in \\1 week": [
            "(\\d+) həftə ərzində"
        ],
        "\\1 week ago": [
            "(\\d+) həftə öncə"
        ],
        "in \\1 day": [
            "(\\d+) gün ərzində"
        ],
        "\\1 day ago": [
            "(\\d+) gün öncə"
        ],
        "in \\1 hour": [
            "(\\d+) saat ərzində"
        ],
        "\\1 hour ago": [
            "(\\d+) saat öncə"
        ],
        "in \\1 minute": [
            "(\\d+) dəqiqə ərzində"
        ],
        "\\1 minute ago": [
            "(\\d+) dəqiqə öncə"
        ],
        "in \\1 second": [
            "(\\d+) saniyə ərzində"
        ],
        "\\1 second ago": [
            "(\\d+) saniyə öncə"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
