# -*- coding: utf-8 -*-
info = {
    "name": "ka",
    "date_order": "DMY",
    "january": [
        "იანვარი",
        "იან"
    ],
    "february": [
        "თებერვალი",
        "თებ"
    ],
    "march": [
        "მარტი",
        "მარ"
    ],
    "april": [
        "აპრილი",
        "აპრ"
    ],
    "may": [
        "მაისი",
        "მაი"
    ],
    "june": [
        "ივნისი",
        "ივნ"
    ],
    "july": [
        "ივლისი",
        "ივლ"
    ],
    "august": [
        "აგვისტო",
        "აგვ"
    ],
    "september": [
        "სექტემბერი",
        "სექ"
    ],
    "october": [
        "ოქტომბერი",
        "ოქტ"
    ],
    "november": [
        "ნოემბერი",
        "ნოე"
    ],
    "december": [
        "დეკემბერი",
        "დეკ"
    ],
    "monday": [
        "ორშაბათი",
        "ორშ"
    ],
    "tuesday": [
        "სამშაბათი",
        "სამ"
    ],
    "wednesday": [
        "ოთხშაბათი",
        "ოთხ"
    ],
    "thursday": [
        "ხუთშაბათი",
        "ხუთ"
    ],
    "friday": [
        "პარასკევი",
        "პარ"
    ],
    "saturday": [
        "შაბათი",
        "შაბ"
    ],
    "sunday": [
        "კვირა",
        "კვი"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "შუადღ შემდეგ",
        "pm"
    ],
    "year": [
        "წელი",
        "წ",
        "წლის"
    ],
    "month": [
        "თვე"
    ],
    "week": [
        "კვირა",
        "კვ"
    ],
    "day": [
        "დღე"
    ],
    "hour": [
        "საათი",
        "სთ"
    ],
    "minute": [
        "წუთი",
        "წთ"
    ],
    "second": [
        "წამი",
        "წმ"
    ],
    "relative-type": {
        "1 year ago": [
            "გასულ წელს"
        ],
        "0 year ago": [
            "ამ წელს"
        ],
        "in 1 year": [
            "მომავალ წელს"
        ],
        "1 month ago": [
            "გასულ თვეს"
        ],
        "0 month ago": [
            "ამ თვეში"
        ],
        "in 1 month": [
            "მომავალ თვეს"
        ],
        "1 week ago": [
            "გასულ კვირაში"
        ],
        "0 week ago": [
            "ამ კვირაში"
        ],
        "in 1 week": [
            "მომავალ კვირაში"
        ],
        "1 day ago": [
            "გუშინ"
        ],
        "0 day ago": [
            "დღეს"
        ],
        "in 1 day": [
            "ხვალ"
        ],
        "0 hour ago": [
            "ამ საათში"
        ],
        "0 minute ago": [
            "ამ წუთში"
        ],
        "0 second ago": [
            "ახლა"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) წელიწადში",
            "(\\d+) წელში"
        ],
        "\\1 year ago": [
            "(\\d+) წლის წინ"
        ],
        "in \\1 month": [
            "(\\d+) თვეში"
        ],
        "\\1 month ago": [
            "(\\d+) თვის წინ"
        ],
        "in \\1 week": [
            "(\\d+) კვირაში"
        ],
        "\\1 week ago": [
            "(\\d+) კვირის წინ",
            "(\\d+) კვ წინ"
        ],
        "in \\1 day": [
            "(\\d+) დღეში"
        ],
        "\\1 day ago": [
            "(\\d+) დღის წინ"
        ],
        "in \\1 hour": [
            "(\\d+) საათში"
        ],
        "\\1 hour ago": [
            "(\\d+) საათის წინ",
            "(\\d+) სთ წინ"
        ],
        "in \\1 minute": [
            "(\\d+) წუთში"
        ],
        "\\1 minute ago": [
            "(\\d+) წუთის წინ",
            "(\\d+) წთ წინ"
        ],
        "in \\1 second": [
            "(\\d+) წამში"
        ],
        "\\1 second ago": [
            "(\\d+) წამის წინ",
            "(\\d+) წმ წინ"
        ]
    },
    "locale_specific": {},
    "skip": [
        "ის",
        "ზე",
        "დაახლოებით",
        "და",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "წინ"
    ],
    "in": [
        "დღეიდან"
    ],
    "simplifications": [
        {
            "ერთ": "1"
        }
    ]
}
