# -*- coding: utf-8 -*-
info = {
    "name": "eu",
    "date_order": "YMD",
    "january": [
        "urtarrila",
        "urt"
    ],
    "february": [
        "otsaila",
        "ots"
    ],
    "march": [
        "martxoa",
        "mar"
    ],
    "april": [
        "apirila",
        "api"
    ],
    "may": [
        "maiatza",
        "mai"
    ],
    "june": [
        "ekaina",
        "eka"
    ],
    "july": [
        "uztaila",
        "uzt"
    ],
    "august": [
        "abuztua",
        "abu"
    ],
    "september": [
        "iraila",
        "ira"
    ],
    "october": [
        "urria",
        "urr"
    ],
    "november": [
        "azaroa",
        "aza"
    ],
    "december": [
        "abendua",
        "abe"
    ],
    "monday": [
        "astelehena",
        "al"
    ],
    "tuesday": [
        "asteartea",
        "ar"
    ],
    "wednesday": [
        "asteazkena",
        "az"
    ],
    "thursday": [
        "osteguna",
        "og"
    ],
    "friday": [
        "ostirala",
        "or"
    ],
    "saturday": [
        "larunbata",
        "lr"
    ],
    "sunday": [
        "igandea",
        "ig"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "urtea"
    ],
    "month": [
        "hilabetea",
        "hil"
    ],
    "week": [
        "astea",
        "ast"
    ],
    "day": [
        "eguna",
        "eg"
    ],
    "hour": [
        "ordua",
        "h"
    ],
    "minute": [
        "minutua",
        "min"
    ],
    "second": [
        "segundoa",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "aurreko urtea"
        ],
        "0 year ago": [
            "aurten"
        ],
        "in 1 year": [
            "hurrengo urtea"
        ],
        "1 month ago": [
            "aurreko hilabetea"
        ],
        "0 month ago": [
            "hilabete hau"
        ],
        "in 1 month": [
            "hurrengo hilabetea"
        ],
        "1 week ago": [
            "aurreko astea"
        ],
        "0 week ago": [
            "aste hau"
        ],
        "in 1 week": [
            "hurrengo astea"
        ],
        "1 day ago": [
            "atzo"
        ],
        "0 day ago": [
            "gaur"
        ],
        "in 1 day": [
            "bihar"
        ],
        "0 hour ago": [
            "ordu honetan"
        ],
        "0 minute ago": [
            "minutu honetan"
        ],
        "0 second ago": [
            "orain"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) urte barru"
        ],
        "\\1 year ago": [
            "duela (\\d+) urte"
        ],
        "in \\1 month": [
            "(\\d+) hilabete barru"
        ],
        "\\1 month ago": [
            "duela (\\d+) hilabete"
        ],
        "in \\1 week": [
            "(\\d+) aste barru"
        ],
        "\\1 week ago": [
            "duela (\\d+) aste"
        ],
        "in \\1 day": [
            "(\\d+) egun barru"
        ],
        "\\1 day ago": [
            "duela (\\d+) egun"
        ],
        "in \\1 hour": [
            "(\\d+) ordu barru"
        ],
        "\\1 hour ago": [
            "duela (\\d+) ordu"
        ],
        "in \\1 minute": [
            "(\\d+) minutu barru"
        ],
        "\\1 minute ago": [
            "duela (\\d+) minutu"
        ],
        "in \\1 second": [
            "(\\d+) segundo barru"
        ],
        "\\1 second ago": [
            "duela (\\d+) segundo"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
