# -*- coding: utf-8 -*-
info = {
    "name": "rm",
    "date_order": "DMY",
    "january": [
        "schaner",
        "schan"
    ],
    "february": [
        "favrer",
        "favr"
    ],
    "march": [
        "mars"
    ],
    "april": [
        "avrigl",
        "avr"
    ],
    "may": [
        "matg"
    ],
    "june": [
        "zercladur",
        "zercl"
    ],
    "july": [
        "fanadur",
        "fan"
    ],
    "august": [
        "avust"
    ],
    "september": [
        "settember",
        "sett"
    ],
    "october": [
        "october",
        "oct"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "december",
        "dec"
    ],
    "monday": [
        "glindesdi",
        "gli"
    ],
    "tuesday": [
        "mardi",
        "ma"
    ],
    "wednesday": [
        "mesemna",
        "me"
    ],
    "thursday": [
        "gievgia",
        "gie"
    ],
    "friday": [
        "venderdi",
        "ve"
    ],
    "saturday": [
        "sonda",
        "so"
    ],
    "sunday": [
        "dumengia",
        "du"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "onn"
    ],
    "month": [
        "mais"
    ],
    "week": [
        "emna"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "ura"
    ],
    "minute": [
        "minuta"
    ],
    "second": [
        "secunda"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ier"
        ],
        "0 day ago": [
            "oz"
        ],
        "in 1 day": [
            "damaun"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
