# -*- coding: utf-8 -*-
info = {
    "name": "ce",
    "date_order": "YMD",
    "january": [
        "январь",
        "янв"
    ],
    "february": [
        "февраль",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "апрель",
        "апр"
    ],
    "may": [
        "май"
    ],
    "june": [
        "июнь",
        "июн"
    ],
    "july": [
        "июль",
        "июл"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "сентябрь",
        "сен"
    ],
    "october": [
        "октябрь",
        "окт"
    ],
    "november": [
        "ноябрь",
        "ноя"
    ],
    "december": [
        "декабрь",
        "дек"
    ],
    "monday": [
        "оршотан де"
    ],
    "tuesday": [
        "шинарин де"
    ],
    "wednesday": [
        "кхаарин де"
    ],
    "thursday": [
        "еарин де"
    ],
    "friday": [
        "пӏераскан де"
    ],
    "saturday": [
        "шот де"
    ],
    "sunday": [
        "кӏиранан де"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "шо",
        "ш"
    ],
    "month": [
        "бутт",
        "бут"
    ],
    "week": [
        "кӏира",
        "кӏир"
    ],
    "day": [
        "де"
    ],
    "hour": [
        "сахьт",
        "сахь"
    ],
    "minute": [
        "минот",
        "мин"
    ],
    "second": [
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "даханчу шарахь"
        ],
        "0 year ago": [
            "карарчу шарахь"
        ],
        "in 1 year": [
            "рогӏерчу шарахь"
        ],
        "1 month ago": [
            "баханчу баттахь"
        ],
        "0 month ago": [
            "карарчу баттахь"
        ],
        "in 1 month": [
            "рогӏерчу баттахь"
        ],
        "1 week ago": [
            "даханчу кӏирнахь"
        ],
        "0 week ago": [
            "карарчу кӏирнахь"
        ],
        "in 1 week": [
            "рогӏерчу кӏирнахь"
        ],
        "1 day ago": [
            "селхана"
        ],
        "0 day ago": [
            "тахана"
        ],
        "in 1 day": [
            "кхана"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) шо даьлча",
            "(\\d+) ш даьлча"
        ],
        "\\1 year ago": [
            "(\\d+) шо хьалха",
            "(\\d+) ш хьалха"
        ],
        "in \\1 month": [
            "(\\d+) бутт баьлча",
            "(\\d+) б баьлча"
        ],
        "\\1 month ago": [
            "(\\d+) бутт хьалха",
            "(\\d+) б хьалха"
        ],
        "in \\1 week": [
            "(\\d+) кӏира даьлча",
            "(\\d+) кӏир даьлча"
        ],
        "\\1 week ago": [
            "(\\d+) кӏира хьалха",
            "(\\d+) кӏир хьалха"
        ],
        "in \\1 day": [
            "(\\d+) де даьлча",
            "(\\d+) д даьлча"
        ],
        "\\1 day ago": [
            "(\\d+) де хьалха",
            "(\\d+) д хьалха"
        ],
        "in \\1 hour": [
            "(\\d+) сахьт даьлча",
            "(\\d+) сахь даьлча"
        ],
        "\\1 hour ago": [
            "(\\d+) сахьт хьалха",
            "(\\d+) сахь хьалха"
        ],
        "in \\1 minute": [
            "(\\d+) минот яьлча",
            "(\\d+) мин яьлча"
        ],
        "\\1 minute ago": [
            "(\\d+) минот хьалха",
            "(\\d+) мин хьалха"
        ],
        "in \\1 second": [
            "(\\d+) секунд яьлча",
            "(\\d+) сек яьлча"
        ],
        "\\1 second ago": [
            "(\\d+) секунд хьалха",
            "(\\d+) сек хьалха"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
