# -*- coding: utf-8 -*-
info = {
    "name": "bs-Latn",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "septembar",
        "sep"
    ],
    "october": [
        "oktobar",
        "okt"
    ],
    "november": [
        "novembar",
        "nov"
    ],
    "december": [
        "decembar",
        "dec"
    ],
    "monday": [
        "ponedjeljak",
        "pon"
    ],
    "tuesday": [
        "utorak",
        "uto"
    ],
    "wednesday": [
        "srijeda",
        "sri"
    ],
    "thursday": [
        "četvrtak",
        "čet"
    ],
    "friday": [
        "petak",
        "pet"
    ],
    "saturday": [
        "subota",
        "sub"
    ],
    "sunday": [
        "nedjelja",
        "ned"
    ],
    "am": [
        "prijepodne"
    ],
    "pm": [
        "popodne"
    ],
    "year": [
        "godina",
        "god",
        "g"
    ],
    "month": [
        "mjesec",
        "mj"
    ],
    "week": [
        "sedmica",
        "sed"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "sat",
        "h"
    ],
    "minute": [
        "minuta",
        "min"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "prošle godine"
        ],
        "0 year ago": [
            "ove godine"
        ],
        "in 1 year": [
            "sljedeće godine"
        ],
        "1 month ago": [
            "prošli mjesec"
        ],
        "0 month ago": [
            "ovaj mjesec"
        ],
        "in 1 month": [
            "sljedeći mjesec"
        ],
        "1 week ago": [
            "prošle sedmice"
        ],
        "0 week ago": [
            "ove sedmice"
        ],
        "in 1 week": [
            "sljedeće sedmice"
        ],
        "1 day ago": [
            "jučer"
        ],
        "0 day ago": [
            "danas"
        ],
        "in 1 day": [
            "sutra"
        ],
        "0 hour ago": [
            "ovaj sat"
        ],
        "0 minute ago": [
            "ova minuta"
        ],
        "0 second ago": [
            "sada"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) godinu",
            "za (\\d+) godina",
            "za (\\d+) god",
            "za (\\d+) g"
        ],
        "\\1 year ago": [
            "prije (\\d+) godinu",
            "prije (\\d+) godina",
            "prije (\\d+) god",
            "prije (\\d+) g"
        ],
        "in \\1 month": [
            "za (\\d+) mjesec",
            "za (\\d+) mjeseci",
            "za (\\d+) mj"
        ],
        "\\1 month ago": [
            "prije (\\d+) mjesec",
            "prije (\\d+) mjeseci",
            "prije (\\d+) mj"
        ],
        "in \\1 week": [
            "za (\\d+) sedmicu",
            "za (\\d+) sedmica",
            "za (\\d+) sed"
        ],
        "\\1 week ago": [
            "prije (\\d+) sedmicu",
            "prije (\\d+) sedmica",
            "prije (\\d+) sed"
        ],
        "in \\1 day": [
            "za (\\d+) dan",
            "za (\\d+) dana",
            "za (\\d+) d"
        ],
        "\\1 day ago": [
            "prije (\\d+) dan",
            "prije (\\d+) dana",
            "prije (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) sat",
            "za (\\d+) sati"
        ],
        "\\1 hour ago": [
            "prije (\\d+) sat",
            "prije (\\d+) sati"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minuta",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "prije (\\d+) minutu",
            "prije (\\d+) minuta",
            "prije (\\d+) min"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundi",
            "za (\\d+) sek"
        ],
        "\\1 second ago": [
            "prije (\\d+) sekundu",
            "prije (\\d+) sekundi",
            "prije (\\d+) sek"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
