# -*- coding: utf-8 -*-
info = {
    "name": "dav",
    "date_order": "DMY",
    "january": [
        "mori ghwa imbiri",
        "imb"
    ],
    "february": [
        "mori ghwa kawi",
        "kaw"
    ],
    "march": [
        "mori ghwa kadadu",
        "kad"
    ],
    "april": [
        "mori ghwa kana",
        "kan"
    ],
    "may": [
        "mori ghwa kasanu",
        "kas"
    ],
    "june": [
        "mori ghwa karandadu",
        "kar"
    ],
    "july": [
        "mori ghwa mfungade",
        "mfu"
    ],
    "august": [
        "mori ghwa wunyanya",
        "wun"
    ],
    "september": [
        "mori ghwa ikenda",
        "ike"
    ],
    "october": [
        "mori ghwa ikumi",
        "iku"
    ],
    "november": [
        "mori ghwa ikumi na imweri",
        "imw"
    ],
    "december": [
        "mori ghwa ikumi na iwi",
        "iwi"
    ],
    "monday": [
        "kuramuka jimweri",
        "jim"
    ],
    "tuesday": [
        "kuramuka kawi",
        "kaw"
    ],
    "wednesday": [
        "kuramuka kadadu",
        "kad"
    ],
    "thursday": [
        "kuramuka kana",
        "kan"
    ],
    "friday": [
        "kuramuka kasanu",
        "kas"
    ],
    "saturday": [
        "kifula nguwo",
        "ngu"
    ],
    "sunday": [
        "ituku ja jumwa",
        "jum"
    ],
    "am": [
        "luma lwa k"
    ],
    "pm": [
        "luma lwa p"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mori"
    ],
    "week": [
        "juma"
    ],
    "day": [
        "ituku"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "iguo"
        ],
        "0 day ago": [
            "idime"
        ],
        "in 1 day": [
            "kesho"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
