# -*- coding: utf-8 -*-
info = {
    "name": "kl",
    "date_order": "YMD",
    "january": [
        "januari",
        "jan"
    ],
    "february": [
        "februari",
        "feb"
    ],
    "march": [
        "martsi",
        "mar"
    ],
    "april": [
        "aprili",
        "apr"
    ],
    "may": [
        "maji",
        "maj"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "augustusi",
        "aug"
    ],
    "september": [
        "septemberi",
        "sep"
    ],
    "october": [
        "oktoberi",
        "okt"
    ],
    "november": [
        "novemberi",
        "nov"
    ],
    "december": [
        "decemberi",
        "dec"
    ],
    "monday": [
        "ataasinngorneq",
        "ata"
    ],
    "tuesday": [
        "marlunngorneq",
        "mar"
    ],
    "wednesday": [
        "pingasunngorneq",
        "pin"
    ],
    "thursday": [
        "sisamanngorneq",
        "sis"
    ],
    "friday": [
        "tallimanngorneq",
        "tal"
    ],
    "saturday": [
        "arfininngorneq",
        "arf"
    ],
    "sunday": [
        "sabaat",
        "sab"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "0 day ago": [
            "today"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) ukioq"
        ],
        "\\1 year ago": [
            "for (\\d+) ukioq siden"
        ],
        "in \\1 month": [
            "om (\\d+) qaammat"
        ],
        "\\1 month ago": [
            "for (\\d+) qaammat siden"
        ],
        "in \\1 week": [
            "om (\\d+) sapaatip-akunnera"
        ],
        "\\1 week ago": [
            "for (\\d+) sapaatip-akunnera siden"
        ],
        "in \\1 day": [
            "om (\\d+) ulloq unnuarlu"
        ],
        "\\1 day ago": [
            "for (\\d+) ulloq unnuarlu siden"
        ],
        "in \\1 hour": [
            "om (\\d+) nalunaaquttap-akunnera"
        ],
        "\\1 hour ago": [
            "for (\\d+) nalunaaquttap-akunnera siden"
        ],
        "in \\1 minute": [
            "om (\\d+) minutsi"
        ],
        "\\1 minute ago": [
            "for (\\d+) minutsi siden"
        ],
        "in \\1 second": [
            "om (\\d+) sekundi"
        ],
        "\\1 second ago": [
            "for (\\d+) sekundi siden"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
