# -*- coding: utf-8 -*-
info = {
    "name": "wae",
    "date_order": "YMD",
    "january": [
        "jenner",
        "jen"
    ],
    "february": [
        "hornig",
        "hor"
    ],
    "march": [
        "märze",
        "mär"
    ],
    "april": [
        "abrille",
        "abr"
    ],
    "may": [
        "meije",
        "mei"
    ],
    "june": [
        "bráčet",
        "brá"
    ],
    "july": [
        "heiwet",
        "hei"
    ],
    "august": [
        "öigšte",
        "öig"
    ],
    "september": [
        "herbštmánet",
        "her"
    ],
    "october": [
        "wímánet",
        "wím"
    ],
    "november": [
        "wintermánet",
        "win"
    ],
    "december": [
        "chrištmánet",
        "chr"
    ],
    "monday": [
        "mäntag",
        "män"
    ],
    "tuesday": [
        "zištag",
        "ziš"
    ],
    "wednesday": [
        "mittwuč",
        "mit"
    ],
    "thursday": [
        "fróntag",
        "fró"
    ],
    "friday": [
        "fritag",
        "fri"
    ],
    "saturday": [
        "samštag",
        "sam"
    ],
    "sunday": [
        "sunntag",
        "sun"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "jár"
    ],
    "month": [
        "mánet"
    ],
    "week": [
        "wuča"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "schtund"
    ],
    "minute": [
        "mínütta"
    ],
    "second": [
        "sekunda"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "gešter"
        ],
        "0 day ago": [
            "hitte"
        ],
        "in 1 day": [
            "móre"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "i (\\d+) jár"
        ],
        "\\1 year ago": [
            "vor (\\d+) jár",
            "cor (\\d+) jár"
        ],
        "in \\1 month": [
            "i (\\d+) mánet"
        ],
        "\\1 month ago": [
            "vor (\\d+) mánet"
        ],
        "in \\1 week": [
            "i (\\d+) wuča",
            "i (\\d+) wučä"
        ],
        "\\1 week ago": [
            "vor (\\d+) wuča",
            "cor (\\d+) wučä"
        ],
        "in \\1 day": [
            "i (\\d+) tag",
            "i (\\d+) täg"
        ],
        "\\1 day ago": [
            "vor (\\d+) tag",
            "vor (\\d+) täg"
        ],
        "in \\1 hour": [
            "i (\\d+) stund",
            "i (\\d+) stunde"
        ],
        "\\1 hour ago": [
            "vor (\\d+) stund",
            "vor (\\d+) stunde"
        ],
        "in \\1 minute": [
            "i (\\d+) minüta",
            "i (\\d+) minüte"
        ],
        "\\1 minute ago": [
            "vor (\\d+) minüta",
            "vor (\\d+) minüte"
        ],
        "in \\1 second": [
            "i (\\d+) sekund",
            "i (\\d+) sekunde"
        ],
        "\\1 second ago": [
            "vor (\\d+) sekund",
            "vor (\\d+) sekunde"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
