# -*- coding: utf-8 -*-
info = {
    "name": "kk",
    "date_order": "DMY",
    "january": [
        "қаңтар",
        "қаң"
    ],
    "february": [
        "ақпан",
        "ақп"
    ],
    "march": [
        "наурыз",
        "нау"
    ],
    "april": [
        "сәуір",
        "сәу"
    ],
    "may": [
        "мамыр",
        "мам"
    ],
    "june": [
        "маусым",
        "мау"
    ],
    "july": [
        "шілде",
        "шіл"
    ],
    "august": [
        "тамыз",
        "там"
    ],
    "september": [
        "қыркүйек",
        "қыр"
    ],
    "october": [
        "қазан",
        "қаз"
    ],
    "november": [
        "қараша",
        "қар"
    ],
    "december": [
        "желтоқсан",
        "жел"
    ],
    "monday": [
        "дүйсенбі",
        "дс"
    ],
    "tuesday": [
        "сейсенбі",
        "сс"
    ],
    "wednesday": [
        "сәрсенбі",
        "ср"
    ],
    "thursday": [
        "бейсенбі",
        "бс"
    ],
    "friday": [
        "жұма",
        "жм"
    ],
    "saturday": [
        "сенбі",
        "сб"
    ],
    "sunday": [
        "жексенбі",
        "жс"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "жыл",
        "ж"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "апта",
        "ап"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "сағат",
        "сағ"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "с"
    ],
    "relative-type": {
        "1 year ago": [
            "былтырғы жыл"
        ],
        "0 year ago": [
            "биылғы жыл"
        ],
        "in 1 year": [
            "келесі жыл"
        ],
        "1 month ago": [
            "өткен ай"
        ],
        "0 month ago": [
            "осы ай"
        ],
        "in 1 month": [
            "келесі ай"
        ],
        "1 week ago": [
            "өткен апта"
        ],
        "0 week ago": [
            "осы апта"
        ],
        "in 1 week": [
            "келесі апта"
        ],
        "1 day ago": [
            "кеше"
        ],
        "0 day ago": [
            "бүгін"
        ],
        "in 1 day": [
            "ертең"
        ],
        "0 hour ago": [
            "осы сағат"
        ],
        "0 minute ago": [
            "осы минут"
        ],
        "0 second ago": [
            "қазір"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жылдан кейін",
            "(\\d+) ж кейін"
        ],
        "\\1 year ago": [
            "(\\d+) жыл бұрын",
            "(\\d+) ж бұрын"
        ],
        "in \\1 month": [
            "(\\d+) айдан кейін"
        ],
        "\\1 month ago": [
            "(\\d+) ай бұрын"
        ],
        "in \\1 week": [
            "(\\d+) аптадан кейін",
            "(\\d+) ап кейін"
        ],
        "\\1 week ago": [
            "(\\d+) апта бұрын",
            "(\\d+) ап бұрын"
        ],
        "in \\1 day": [
            "(\\d+) күннен кейін"
        ],
        "\\1 day ago": [
            "(\\d+) күн бұрын"
        ],
        "in \\1 hour": [
            "(\\d+) сағаттан кейін",
            "(\\d+) сағ кейін"
        ],
        "\\1 hour ago": [
            "(\\d+) сағат бұрын",
            "(\\d+) сағ бұрын"
        ],
        "in \\1 minute": [
            "(\\d+) минуттан кейін",
            "(\\d+) мин кейін"
        ],
        "\\1 minute ago": [
            "(\\d+) минут бұрын",
            "(\\d+) мин бұрын"
        ],
        "in \\1 second": [
            "(\\d+) секундтан кейін",
            "(\\d+) сек кейін"
        ],
        "\\1 second ago": [
            "(\\d+) секунд бұрын",
            "(\\d+) сек бұрын"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
