# -*- coding: utf-8 -*-
info = {
    "name": "sr",
    "date_order": "DMY",
    "january": [
        "јануар",
        "јан"
    ],
    "february": [
        "фебруар",
        "феб"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "април",
        "апр"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јун"
    ],
    "july": [
        "јул"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "септембар",
        "сеп"
    ],
    "october": [
        "октобар",
        "окт"
    ],
    "november": [
        "новембар",
        "нов"
    ],
    "december": [
        "децембар",
        "дец"
    ],
    "monday": [
        "понедељак",
        "пон"
    ],
    "tuesday": [
        "уторак",
        "уто"
    ],
    "wednesday": [
        "среда",
        "сре"
    ],
    "thursday": [
        "четвртак",
        "чет"
    ],
    "friday": [
        "петак",
        "пет"
    ],
    "saturday": [
        "субота",
        "суб"
    ],
    "sunday": [
        "недеља",
        "нед"
    ],
    "am": [
        "пре подне"
    ],
    "pm": [
        "по подне"
    ],
    "year": [
        "година",
        "год",
        "г"
    ],
    "month": [
        "месец",
        "мес",
        "м"
    ],
    "week": [
        "недеља",
        "нед",
        "н"
    ],
    "day": [
        "дан",
        "д"
    ],
    "hour": [
        "сат",
        "ч"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "сек",
        "с"
    ],
    "relative-type": {
        "1 year ago": [
            "прошле године"
        ],
        "0 year ago": [
            "ове године"
        ],
        "in 1 year": [
            "следеће године"
        ],
        "1 month ago": [
            "прошлог месеца"
        ],
        "0 month ago": [
            "овог месеца"
        ],
        "in 1 month": [
            "следећег месеца"
        ],
        "1 week ago": [
            "прошле недеље"
        ],
        "0 week ago": [
            "ове недеље"
        ],
        "in 1 week": [
            "следеће недеље"
        ],
        "1 day ago": [
            "јуче"
        ],
        "0 day ago": [
            "данас"
        ],
        "in 1 day": [
            "сутра"
        ],
        "0 hour ago": [
            "овог сата"
        ],
        "0 minute ago": [
            "овог минута"
        ],
        "0 second ago": [
            "сада"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "за (\\d+) годину",
            "за (\\d+) година",
            "за (\\d+) год",
            "за (\\d+) г"
        ],
        "\\1 year ago": [
            "пре (\\d+) године",
            "пре (\\d+) година",
            "пре (\\d+) год",
            "пре (\\d+) г"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци",
            "за (\\d+) мес",
            "за (\\d+) м"
        ],
        "\\1 month ago": [
            "пре (\\d+) месеца",
            "пре (\\d+) месеци",
            "пре (\\d+) мес",
            "пре (\\d+) м"
        ],
        "in \\1 week": [
            "за (\\d+) недељу",
            "за (\\d+) недеља",
            "за (\\d+) нед",
            "за (\\d+) н"
        ],
        "\\1 week ago": [
            "пре (\\d+) недеље",
            "пре (\\d+) недеља",
            "пре (\\d+) нед",
            "пре (\\d+) н"
        ],
        "in \\1 day": [
            "за (\\d+) дан",
            "за (\\d+) дана",
            "за (\\d+) д"
        ],
        "\\1 day ago": [
            "пре (\\d+) дана",
            "пре (\\d+) д"
        ],
        "in \\1 hour": [
            "за (\\d+) сат",
            "за (\\d+) сати",
            "за (\\d+) ч"
        ],
        "\\1 hour ago": [
            "пре (\\d+) сата",
            "пре (\\d+) сати",
            "пре (\\d+) ч"
        ],
        "in \\1 minute": [
            "за (\\d+) минут",
            "за (\\d+) минута",
            "за (\\d+) мин"
        ],
        "\\1 minute ago": [
            "пре (\\d+) минута",
            "пре (\\d+) мин"
        ],
        "in \\1 second": [
            "за (\\d+) секунду",
            "за (\\d+) секунди",
            "за (\\d+) сек",
            "за (\\d+) с"
        ],
        "\\1 second ago": [
            "пре (\\d+) секунде",
            "пре (\\d+) секунди",
            "пре (\\d+) сек",
            "пре (\\d+) с"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
