# -*- coding: utf-8 -*-
info = {
    "name": "ig",
    "date_order": "DMY",
    "january": [
        "jenụwarị",
        "jen"
    ],
    "february": [
        "febrụwarị",
        "feb"
    ],
    "march": [
        "maachị",
        "maa"
    ],
    "april": [
        "eprel",
        "epr"
    ],
    "may": [
        "mee"
    ],
    "june": [
        "juun",
        "juu"
    ],
    "july": [
        "julaị",
        "jul"
    ],
    "august": [
        "ọgọọst",
        "ọgọ"
    ],
    "september": [
        "septemba",
        "sep"
    ],
    "october": [
        "ọktoba",
        "ọkt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "disemba",
        "dis"
    ],
    "monday": [
        "mọnde",
        "mọn"
    ],
    "tuesday": [
        "tiuzdee",
        "tiu"
    ],
    "wednesday": [
        "wenezdee",
        "wen"
    ],
    "thursday": [
        "tọọzdee",
        "tọọ"
    ],
    "friday": [
        "fraịdee",
        "fraị"
    ],
    "saturday": [
        "satọdee",
        "sat"
    ],
    "sunday": [
        "mbọsị ụka",
        "ụka"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "afọ"
    ],
    "month": [
        "ọnwa"
    ],
    "week": [
        "izu"
    ],
    "day": [
        "ụbọchị"
    ],
    "hour": [
        "elekere"
    ],
    "minute": [
        "nkeji"
    ],
    "second": [
        "nkejinta"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nnyaafụ"
        ],
        "0 day ago": [
            "taata"
        ],
        "in 1 day": [
            "echi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
