# -*- coding: utf-8 -*-
info = {
    "name": "nd",
    "date_order": "DMY",
    "january": [
        "zibandlela",
        "zib"
    ],
    "february": [
        "nhlolanja",
        "nhlo"
    ],
    "march": [
        "mbimbitho",
        "mbi"
    ],
    "april": [
        "mabasa",
        "mab"
    ],
    "may": [
        "nkwenkwezi",
        "nkw"
    ],
    "june": [
        "nhlangula",
        "nhla"
    ],
    "july": [
        "ntulikazi",
        "ntu"
    ],
    "august": [
        "ncwabakazi",
        "ncw"
    ],
    "september": [
        "mpandula",
        "mpan"
    ],
    "october": [
        "mfumfu",
        "mfu"
    ],
    "november": [
        "lwezi",
        "lwe"
    ],
    "december": [
        "mpalakazi",
        "mpal"
    ],
    "monday": [
        "mvulo",
        "mvu"
    ],
    "tuesday": [
        "sibili",
        "sib"
    ],
    "wednesday": [
        "sithathu",
        "sit"
    ],
    "thursday": [
        "sine",
        "sin"
    ],
    "friday": [
        "sihlanu",
        "sih"
    ],
    "saturday": [
        "mgqibelo",
        "mgq"
    ],
    "sunday": [
        "sonto",
        "son"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "umnyaka"
    ],
    "month": [
        "inyangacale"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "ilanga"
    ],
    "hour": [
        "ihola"
    ],
    "minute": [
        "umuzuzu"
    ],
    "second": [
        "isekendi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "izolo"
        ],
        "0 day ago": [
            "lamuhla"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
