# -*- coding: utf-8 -*-
info = {
    "name": "nus",
    "date_order": "DMY",
    "january": [
        "tiop thar pɛt",
        "tiop"
    ],
    "february": [
        "pɛt"
    ],
    "march": [
        "duɔ̱ɔ̱ŋ",
        "duɔ̱ɔ̱"
    ],
    "april": [
        "guak"
    ],
    "may": [
        "duät",
        "duä"
    ],
    "june": [
        "kornyoot",
        "kor"
    ],
    "july": [
        "pay yie̱tni",
        "pay"
    ],
    "august": [
        "tho̱o̱r",
        "thoo"
    ],
    "september": [
        "tɛɛr",
        "tɛɛ"
    ],
    "october": [
        "laath",
        "laa"
    ],
    "november": [
        "kur"
    ],
    "december": [
        "tio̱p in di̱i̱t",
        "tid"
    ],
    "monday": [
        "jiec la̱t",
        "jiec"
    ],
    "tuesday": [
        "rɛw lätni",
        "rɛw"
    ],
    "wednesday": [
        "diɔ̱k lätni",
        "diɔ̱k"
    ],
    "thursday": [
        "ŋuaan lätni",
        "ŋuaan"
    ],
    "friday": [
        "dhieec lätni",
        "dhieec"
    ],
    "saturday": [
        "bäkɛl lätni",
        "bäkɛl"
    ],
    "sunday": [
        "cäŋ kuɔth",
        "cäŋ"
    ],
    "am": [
        "rw"
    ],
    "pm": [
        "tŋ"
    ],
    "year": [
        "ruɔ̱n"
    ],
    "month": [
        "pay"
    ],
    "week": [
        "jiɔk"
    ],
    "day": [
        "cäŋ"
    ],
    "hour": [
        "thaak"
    ],
    "minute": [
        "minit"
    ],
    "second": [
        "thɛkɛni"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "pan"
        ],
        "0 day ago": [
            "walɛ"
        ],
        "in 1 day": [
            "ruun"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
