# -*- coding: utf-8 -*-
info = {
    "%%spellout-cardinal-feminine-accusative": {
        "(0, 1)": "ERROR;",
        "2": "dvi;",
        "3": "tris;",
        "4": "keturias;",
        "5": "penkias;",
        "6": "šešias;",
        "7": "septynias;",
        "8": "aštuonias;",
        "9": "devynias;",
        "(10, 'inf')": "ERROR;"
    },
    "%%spellout-thousands": {
        "0": "tūkstančių;",
        "1": "=%spellout-cardinal-masculine= tūkstantis;",
        "(2, 9)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "(10, 20)": "=%spellout-cardinal-masculine= tūkstančių;",
        "21": "=%spellout-cardinal-masculine= tūkstantis;",
        "(22, 29)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "30": "=%spellout-cardinal-masculine= tūkstančių;",
        "31": "=%spellout-cardinal-masculine= tūkstantis;",
        "(32, 39)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "40": "=%spellout-cardinal-masculine= tūkstančių;",
        "41": "=%spellout-cardinal-masculine= tūkstantis;",
        "(42, 49)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "50": "=%spellout-cardinal-masculine= tūkstančių;",
        "51": "=%spellout-cardinal-masculine= tūkstantis;",
        "(52, 59)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "60": "=%spellout-cardinal-masculine= tūkstančių;",
        "61": "=%spellout-cardinal-masculine= tūkstantis;",
        "(62, 69)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "70": "=%spellout-cardinal-masculine= tūkstančių;",
        "71": "=%spellout-cardinal-masculine= tūkstantis;",
        "(72, 79)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "80": "=%spellout-cardinal-masculine= tūkstančių;",
        "81": "=%spellout-cardinal-masculine= tūkstantis;",
        "(82, 89)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "90": "=%spellout-cardinal-masculine= tūkstančių;",
        "91": "=%spellout-cardinal-masculine= tūkstantis;",
        "(92, 99)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "(100, 199)": "šimtas >>;",
        "(200, 'inf')": "<%spellout-cardinal-masculine< šimtai >>;"
    },
    "%spellout-cardinal-feminine": {
        "0": "nulis;",
        "1": "viena;",
        "2": "dvi;",
        "3": "trys;",
        "(4, 9)": "=%spellout-cardinal-masculine=os;",
        "(10, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 99)": "<%%spellout-cardinal-feminine-accusative<dešimt[ >>];",
        "(100, 199)": "šimtas[ >>];",
        "(200, 999)": "<%spellout-cardinal-masculine< šimtai[ >>];",
        "(1000, 999999)": "tūkstantis[ >>];",
        "(1000000, 1999999)": "vienas milijonas[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< milijonų[ >>];",
        "(1000000000, 1999999999)": "vienas milijardas[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< milijardų[ >>];",
        "(1000000000000, 1999999999999)": "vienas trilijonas[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< trilijonų[ >>];",
        "(1000000000000000, 1999999999999999)": "vienas kvadrilijonas[ >>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< kvadrilijonų[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine": {
        "0": "nulis;",
        "1": "vienas;",
        "2": "du;",
        "3": "trys;",
        "4": "keturi;",
        "5": "penki;",
        "6": "šeši;",
        "7": "septyni;",
        "8": "aštuoni;",
        "9": "devyni;",
        "10": "dešimt;",
        "11": "vienuolika;",
        "12": "dvylika;",
        "13": "trylika;",
        "(14, 19)": ">>olika;",
        "(20, 99)": "<%%spellout-cardinal-feminine-accusative<dešimt[ >>];",
        "(100, 199)": "šimtas[ >>];",
        "(200, 999)": "<%spellout-cardinal-masculine< šimtai[ >>];",
        "(1000, 999999)": "tūkstantis[ >>];",
        "(1000000, 1999999)": "vienas milijonas[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< milijonų[ >>];",
        "(1000000000, 1999999999)": "vienas milijardas[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< milijardų[ >>];",
        "(1000000000000, 1999999999999)": "vienas trilijonas[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine<trilijonų[ >>];",
        "(1000000000000000, 1999999999999999)": "vienas kvadrilijonas[ >>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< kvadrilijonų[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-numbering": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-numbering-year": {
        "(0, 'inf')": "=%spellout-numbering=;"
    }
}
