# -*- coding: utf-8 -*-
info = {
    "name": "dsb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan",
        "januara"
    ],
    "february": [
        "februar",
        "feb",
        "februara"
    ],
    "march": [
        "měrc",
        "měr",
        "měrca"
    ],
    "april": [
        "apryl",
        "apr",
        "apryla"
    ],
    "may": [
        "maj",
        "maja"
    ],
    "june": [
        "junij",
        "jun",
        "junija"
    ],
    "july": [
        "julij",
        "jul",
        "julija"
    ],
    "august": [
        "awgust",
        "awg",
        "awgusta"
    ],
    "september": [
        "september",
        "sep",
        "septembra"
    ],
    "october": [
        "oktober",
        "okt",
        "oktobra"
    ],
    "november": [
        "nowember",
        "now",
        "nowembra"
    ],
    "december": [
        "december",
        "dec",
        "decembra"
    ],
    "monday": [
        "pónjeźele",
        "pón"
    ],
    "tuesday": [
        "wałtora",
        "wał"
    ],
    "wednesday": [
        "srjoda",
        "srj"
    ],
    "thursday": [
        "stwórtk",
        "stw"
    ],
    "friday": [
        "pětk",
        "pět"
    ],
    "saturday": [
        "sobota",
        "sob"
    ],
    "sunday": [
        "njeźela",
        "nje"
    ],
    "am": [
        "dopołdnja"
    ],
    "pm": [
        "wótpołdnja"
    ],
    "year": [
        "lěto",
        "l"
    ],
    "month": [
        "mjasec",
        "mjas"
    ],
    "week": [
        "tyźeń",
        "tyź"
    ],
    "day": [
        "źeń",
        "ź"
    ],
    "hour": [
        "góźina",
        "góź",
        "g"
    ],
    "minute": [
        "minuta",
        "min",
        "m"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "łoni"
        ],
        "0 year ago": [
            "lětosa"
        ],
        "in 1 year": [
            "znowa"
        ],
        "1 month ago": [
            "slědny mjasec"
        ],
        "0 month ago": [
            "ten mjasec"
        ],
        "in 1 month": [
            "pśiducy mjasec"
        ],
        "1 week ago": [
            "slědny tyźeń"
        ],
        "0 week ago": [
            "ten tyźeń"
        ],
        "in 1 week": [
            "pśiducy tyźeń"
        ],
        "1 day ago": [
            "cora"
        ],
        "0 day ago": [
            "źinsa"
        ],
        "in 1 day": [
            "witśe"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) lěto",
            "za (\\d+) lět",
            "za (\\d+) l"
        ],
        "\\1 year ago": [
            "pśed (\\d+) lětom",
            "pśed (\\d+) lětami",
            "pśed (\\d+) l"
        ],
        "in \\1 month": [
            "za (\\d+) mjasec",
            "za (\\d+) mjasecow",
            "za (\\d+) mjas"
        ],
        "\\1 month ago": [
            "pśed (\\d+) mjasecom",
            "pśed (\\d+) mjasecami",
            "pśed (\\d+) mjas"
        ],
        "in \\1 week": [
            "za (\\d+) tyźeń",
            "za (\\d+) tyźenjow",
            "za (\\d+) tyź"
        ],
        "\\1 week ago": [
            "pśed (\\d+) tyźenjom",
            "pśed (\\d+) tyźenjami",
            "pśed (\\d+) tyź"
        ],
        "in \\1 day": [
            "za (\\d+) źeń",
            "za (\\d+) dnjow",
            "za (\\d+) dnj",
            "za (\\d+) ź"
        ],
        "\\1 day ago": [
            "pśed (\\d+) dnjom",
            "pśed (\\d+) dnjami",
            "pśed (\\d+) dnj",
            "pśed (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) góźinu",
            "za (\\d+) góźin",
            "za (\\d+) góź",
            "za (\\d+) g"
        ],
        "\\1 hour ago": [
            "pśed (\\d+) góźinu",
            "pśed (\\d+) góźinami",
            "pśed (\\d+) góź",
            "pśed (\\d+) g"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minutow",
            "za (\\d+) min",
            "za (\\d+) m"
        ],
        "\\1 minute ago": [
            "pśed (\\d+) minutu",
            "pśed (\\d+) minutami",
            "pśed (\\d+) min",
            "pśed (\\d+) m"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundow",
            "za (\\d+) sek",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "pśed (\\d+) sekundu",
            "pśed (\\d+) sekundami",
            "pśed (\\d+) sek",
            "pśed (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
