# -*- coding: utf-8 -*-
info = {
    "name": "gl",
    "date_order": "DMY",
    "january": [
        "xaneiro",
        "xan"
    ],
    "february": [
        "febreiro",
        "feb"
    ],
    "march": [
        "marzo",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maio"
    ],
    "june": [
        "xuño"
    ],
    "july": [
        "xullo",
        "xul"
    ],
    "august": [
        "agosto",
        "ago"
    ],
    "september": [
        "setembro",
        "set"
    ],
    "october": [
        "outubro",
        "out"
    ],
    "november": [
        "novembro",
        "nov"
    ],
    "december": [
        "decembro",
        "dec"
    ],
    "monday": [
        "luns"
    ],
    "tuesday": [
        "martes",
        "mar"
    ],
    "wednesday": [
        "mércores",
        "mér"
    ],
    "thursday": [
        "xoves",
        "xov"
    ],
    "friday": [
        "venres",
        "ven"
    ],
    "saturday": [
        "sábado",
        "sáb"
    ],
    "sunday": [
        "domingo",
        "dom"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ano",
        "a"
    ],
    "month": [
        "mes",
        "m"
    ],
    "week": [
        "semana",
        "sem"
    ],
    "day": [
        "día",
        "d"
    ],
    "hour": [
        "hora",
        "h"
    ],
    "minute": [
        "minuto",
        "min"
    ],
    "second": [
        "segundo",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "o ano pasado",
            "ano pasado"
        ],
        "0 year ago": [
            "este ano"
        ],
        "in 1 year": [
            "o próximo ano",
            "seguinte ano"
        ],
        "1 month ago": [
            "o mes pasado",
            "m pasado"
        ],
        "0 month ago": [
            "este mes",
            "este m"
        ],
        "in 1 month": [
            "o próximo mes",
            "m seguinte"
        ],
        "1 week ago": [
            "a semana pasada",
            "sem pasada"
        ],
        "0 week ago": [
            "esta semana",
            "esta sem"
        ],
        "in 1 week": [
            "a próxima semana",
            "sem seguinte"
        ],
        "1 day ago": [
            "onte"
        ],
        "0 day ago": [
            "hoxe"
        ],
        "in 1 day": [
            "mañá"
        ],
        "0 hour ago": [
            "nesta hora"
        ],
        "0 minute ago": [
            "neste minuto"
        ],
        "0 second ago": [
            "agora"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "en (\\d+) ano",
            "en (\\d+) anos",
            "en (\\d+) a"
        ],
        "\\1 year ago": [
            "hai (\\d+) ano",
            "hai (\\d+) anos",
            "hai (\\d+) a"
        ],
        "in \\1 month": [
            "en (\\d+) mes",
            "en (\\d+) meses",
            "en (\\d+) m"
        ],
        "\\1 month ago": [
            "hai (\\d+) mes",
            "hai (\\d+) meses",
            "hai (\\d+) m"
        ],
        "in \\1 week": [
            "en (\\d+) semana",
            "en (\\d+) semanas",
            "en (\\d+) sem"
        ],
        "\\1 week ago": [
            "hai (\\d+) semana",
            "hai (\\d+) semanas",
            "hai (\\d+) sem"
        ],
        "in \\1 day": [
            "en (\\d+) día",
            "en (\\d+) días",
            "en (\\d+) d"
        ],
        "\\1 day ago": [
            "hai (\\d+) día",
            "hai (\\d+) días",
            "hai (\\d+) d"
        ],
        "in \\1 hour": [
            "en (\\d+) hora",
            "en (\\d+) horas",
            "en (\\d+) h"
        ],
        "\\1 hour ago": [
            "hai (\\d+) hora",
            "hai (\\d+) horas",
            "hai (\\d+) h"
        ],
        "in \\1 minute": [
            "en (\\d+) minuto",
            "en (\\d+) minutos",
            "en (\\d+) min"
        ],
        "\\1 minute ago": [
            "hai (\\d+) minuto",
            "hai (\\d+) minutos",
            "hai (\\d+) min"
        ],
        "in \\1 second": [
            "en (\\d+) segundo",
            "en (\\d+) segundos",
            "en (\\d+) s"
        ],
        "\\1 second ago": [
            "hai (\\d+) segundo",
            "hai (\\d+) segundos",
            "hai (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
