# -*- coding: utf-8 -*-
info = {
    "name": "ksh",
    "date_order": "DMY",
    "january": [
        "jannewa",
        "jan"
    ],
    "february": [
        "fäbrowa",
        "fäb"
    ],
    "march": [
        "määz",
        "mäz"
    ],
    "april": [
        "aprell",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juuni",
        "jun"
    ],
    "july": [
        "juuli",
        "jul"
    ],
    "august": [
        "oujoß",
        "ouj"
    ],
    "september": [
        "septämber",
        "säp"
    ],
    "october": [
        "oktohber",
        "okt"
    ],
    "november": [
        "novämber",
        "nov"
    ],
    "december": [
        "dezämber",
        "dez"
    ],
    "monday": [
        "mohndaach",
        "mo"
    ],
    "tuesday": [
        "dinnsdaach",
        "di"
    ],
    "wednesday": [
        "metwoch",
        "me"
    ],
    "thursday": [
        "dunnersdaach",
        "du"
    ],
    "friday": [
        "friidaach",
        "fr"
    ],
    "saturday": [
        "samsdaach",
        "sa"
    ],
    "sunday": [
        "sunndaach",
        "su"
    ],
    "am": [
        "vörmeddaach",
        "vm",
        "uhr vörmiddaachs"
    ],
    "pm": [
        "nommendaach",
        "nm",
        "uhr nommendaachs"
    ],
    "year": [
        "johr",
        "j"
    ],
    "month": [
        "mohnd",
        "m"
    ],
    "week": [
        "woch",
        "w"
    ],
    "day": [
        "daach",
        "d"
    ],
    "hour": [
        "schtund",
        "std",
        "s"
    ],
    "minute": [
        "menutt",
        "min",
        "m"
    ],
    "second": [
        "sekond",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "läz johr"
        ],
        "0 year ago": [
            "diß johr"
        ],
        "in 1 year": [
            "näx johr"
        ],
        "1 month ago": [
            "lätzde mohnd"
        ],
        "0 month ago": [
            "diese mohnd"
        ],
        "in 1 month": [
            "nächste mohnd"
        ],
        "1 week ago": [
            "läz woch"
        ],
        "0 week ago": [
            "di woch"
        ],
        "in 1 week": [
            "nächste woche"
        ],
        "1 day ago": [
            "jestere"
        ],
        "0 day ago": [
            "hück"
        ],
        "in 1 day": [
            "morje"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "en (\\d+) johr",
            "en (\\d+) johre"
        ],
        "\\1 year ago": [
            "vör (\\d+) johr",
            "vör (\\d+) johre"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
