# -*- coding: utf-8 -*-
info = {
    "name": "bm",
    "date_order": "DMY",
    "january": [
        "zanwuye",
        "zan"
    ],
    "february": [
        "feburuye",
        "feb"
    ],
    "march": [
        "marisi",
        "mar"
    ],
    "april": [
        "awirili",
        "awi"
    ],
    "may": [
        "mɛ"
    ],
    "june": [
        "zuwɛn",
        "zuw"
    ],
    "july": [
        "zuluye",
        "zul"
    ],
    "august": [
        "uti"
    ],
    "september": [
        "sɛtanburu",
        "sɛt"
    ],
    "october": [
        "ɔkutɔburu",
        "ɔku"
    ],
    "november": [
        "nowanburu",
        "now"
    ],
    "december": [
        "desanburu",
        "des"
    ],
    "monday": [
        "ntɛnɛ",
        "ntɛ"
    ],
    "tuesday": [
        "tarata",
        "tar"
    ],
    "wednesday": [
        "araba",
        "ara"
    ],
    "thursday": [
        "alamisa",
        "ala"
    ],
    "friday": [
        "juma",
        "jum"
    ],
    "saturday": [
        "sibiri",
        "sib"
    ],
    "sunday": [
        "kari",
        "kar"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "san"
    ],
    "month": [
        "kalo"
    ],
    "week": [
        "dɔgɔkun"
    ],
    "day": [
        "don"
    ],
    "hour": [
        "lɛrɛ"
    ],
    "minute": [
        "miniti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "kunu"
        ],
        "0 day ago": [
            "bi"
        ],
        "in 1 day": [
            "sini"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
