# -*- coding: utf-8 -*-
info = {
    "name": "mzn",
    "date_order": "YMD",
    "january": [
        "ژانویه"
    ],
    "february": [
        "فوریه"
    ],
    "march": [
        "مارس"
    ],
    "april": [
        "آوریل"
    ],
    "may": [
        "مه"
    ],
    "june": [
        "ژوئن"
    ],
    "july": [
        "ژوئیه"
    ],
    "august": [
        "اوت"
    ],
    "september": [
        "سپتامبر"
    ],
    "october": [
        "اکتبر"
    ],
    "november": [
        "نوامبر"
    ],
    "december": [
        "دسامبر"
    ],
    "monday": [
        "mon"
    ],
    "tuesday": [
        "tue"
    ],
    "wednesday": [
        "wed"
    ],
    "thursday": [
        "thu"
    ],
    "friday": [
        "fri"
    ],
    "saturday": [
        "sat"
    ],
    "sunday": [
        "sun"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "سال"
    ],
    "month": [
        "ماه"
    ],
    "week": [
        "هفته"
    ],
    "day": [
        "روز"
    ],
    "hour": [
        "ساعِت",
        "ساعت"
    ],
    "minute": [
        "دقیقه",
        "دَقه"
    ],
    "second": [
        "ثانیه"
    ],
    "relative-type": {
        "1 year ago": [
            "پارسال"
        ],
        "0 year ago": [
            "امسال"
        ],
        "in 1 year": [
            "سال دیگه"
        ],
        "1 month ago": [
            "ماه قبل"
        ],
        "0 month ago": [
            "این ماه"
        ],
        "in 1 month": [
            "ماه ِبعد"
        ],
        "1 week ago": [
            "قبلی هفته"
        ],
        "0 week ago": [
            "این هفته"
        ],
        "in 1 week": [
            "بعدی هفته"
        ],
        "1 day ago": [
            "دیروز"
        ],
        "0 day ago": [
            "اَمروز"
        ],
        "in 1 day": [
            "فِردا"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) سال دله"
        ],
        "\\1 year ago": [
            "(\\d+) سال پیش"
        ],
        "in \\1 month": [
            "(\\d+) ماه دله"
        ],
        "\\1 month ago": [
            "(\\d+) ماه پیش"
        ],
        "in \\1 week": [
            "(\\d+) هفته دله"
        ],
        "\\1 week ago": [
            "(\\d+) هفته پیش"
        ],
        "in \\1 day": [
            "(\\d+) روز دله"
        ],
        "\\1 day ago": [
            "(\\d+) روز پیش"
        ],
        "in \\1 hour": [
            "(\\d+) ساعِت دله",
            "(\\d+) ساعت دله"
        ],
        "\\1 hour ago": [
            "(\\d+) ساعِت پیش",
            "(\\d+) ساعت پیش"
        ],
        "in \\1 minute": [
            "(\\d+) دقیقه دله",
            "(\\d+) دَقه دله"
        ],
        "\\1 minute ago": [
            "(\\d+) دَقه پیش"
        ],
        "in \\1 second": [
            "(\\d+) ثانیه دله"
        ],
        "\\1 second ago": [
            "(\\d+) ثانیه پیش"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
