# -*- coding: utf-8 -*-
info = {
    "name": "cgg",
    "date_order": "DMY",
    "january": [
        "okwokubanza",
        "kbz"
    ],
    "february": [
        "okwakabiri",
        "kbr"
    ],
    "march": [
        "okwakashatu",
        "kst"
    ],
    "april": [
        "okwakana",
        "kkn"
    ],
    "may": [
        "okwakataana",
        "ktn"
    ],
    "june": [
        "okwamukaaga",
        "kmk"
    ],
    "july": [
        "okwamushanju",
        "kms"
    ],
    "august": [
        "okwamunaana",
        "kmn"
    ],
    "september": [
        "okwamwenda",
        "kmw"
    ],
    "october": [
        "okwaikumi",
        "kkm"
    ],
    "november": [
        "okwaikumi na kumwe",
        "knk"
    ],
    "december": [
        "okwaikumi na ibiri",
        "knb"
    ],
    "monday": [
        "orwokubanza",
        "ork"
    ],
    "tuesday": [
        "orwakabiri",
        "okb"
    ],
    "wednesday": [
        "orwakashatu",
        "oks"
    ],
    "thursday": [
        "orwakana",
        "okn"
    ],
    "friday": [
        "orwakataano",
        "okt"
    ],
    "saturday": [
        "orwamukaaga",
        "omk"
    ],
    "sunday": [
        "sande",
        "san"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "omwaka"
    ],
    "month": [
        "omwezi"
    ],
    "week": [
        "esande"
    ],
    "day": [
        "eizooba"
    ],
    "hour": [
        "shaaha"
    ],
    "minute": [
        "edakiika"
    ],
    "second": [
        "obucweka/esekendi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nyomwabazyo"
        ],
        "0 day ago": [
            "erizooba"
        ],
        "in 1 day": [
            "nyenkyakare"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
