# -*- coding: utf-8 -*-
info = {
    "name": "dua",
    "date_order": "DMY",
    "january": [
        "dimɔ́di",
        "di"
    ],
    "february": [
        "ŋgɔndɛ",
        "ŋgɔn"
    ],
    "march": [
        "sɔŋɛ",
        "sɔŋ"
    ],
    "april": [
        "diɓáɓá",
        "diɓ"
    ],
    "may": [
        "emiasele",
        "emi"
    ],
    "june": [
        "esɔpɛsɔpɛ",
        "esɔ"
    ],
    "july": [
        "madiɓɛ́díɓɛ́",
        "mad"
    ],
    "august": [
        "diŋgindi",
        "diŋ"
    ],
    "september": [
        "nyɛtɛki",
        "nyɛt"
    ],
    "october": [
        "mayésɛ́",
        "may"
    ],
    "november": [
        "tiníní",
        "tin"
    ],
    "december": [
        "eláŋgɛ́",
        "elá"
    ],
    "monday": [
        "mɔ́sú",
        "mɔ́s"
    ],
    "tuesday": [
        "kwasú",
        "kwa"
    ],
    "wednesday": [
        "mukɔ́sú",
        "muk"
    ],
    "thursday": [
        "ŋgisú",
        "ŋgi"
    ],
    "friday": [
        "ɗónɛsú",
        "ɗón"
    ],
    "saturday": [
        "esaɓasú",
        "esa"
    ],
    "sunday": [
        "éti",
        "ét"
    ],
    "am": [
        "idiɓa"
    ],
    "pm": [
        "ebyámu"
    ],
    "year": [
        "mbú"
    ],
    "month": [
        "mɔ́di"
    ],
    "week": [
        "disama"
    ],
    "day": [
        "búnyá"
    ],
    "hour": [
        "ŋgandɛ"
    ],
    "minute": [
        "ndɔkɔ"
    ],
    "second": [
        "píndí"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "kíɛlɛ nítómb́í"
        ],
        "0 day ago": [
            "wɛ́ŋgɛ̄"
        ],
        "in 1 day": [
            "kíɛlɛ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
